@@ -628,7 +628,7 @@ static PetscErrorCode DMPlexEGADSLitePrintModel_Internal(ego model)
 - filename - The name of the EGADSLite file
 
   Output Parameter:
-. dm       - The DM object representing the mesh
+. dm - The DM object representing the mesh
 
   Level: beginner
 
@@ -643,7 +643,7 @@ PetscErrorCode DMPlexCreateEGADSLiteFromFile(MPI_Comm comm, const char filename[
   PetscBool printModel = PETSC_FALSE;
 
   PetscFunctionBegin;
-  PetscValidCharPointer(filename, 2);
+  PetscAssertPointer(filename, 2);
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-dm_plex_egads_print_model", &printModel, NULL));
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
 #if defined(PETSC_HAVE_EGADS)
