@@ -2,30 +2,28 @@
 #include <petscviewerhdf5.h>
 #include <petscsf.h>
 
-static const char help[] = "Load and save the mesh to the native HDF5 format\n\n";
-static const char EX[] = "ex56.c";
-static const char LABEL_NAME[] = "BoundaryVertices";
-static const PetscInt LABEL_VALUE = 12345;
+static const char help[] = "Test DMLabel I/O with PETSc native HDF5 mesh format\n\n";
+static const char EX[]   = "ex56.c";
 typedef struct {
   MPI_Comm    comm;
-  const char *meshname;                     /* Mesh name */
-  PetscBool   compare;                      /* Compare the meshes using DMPlexEqual() and DMCompareLabels() */
-  PetscBool   compare_labels;               /* Compare labels in the meshes using DMCompareLabels() */
-  PetscBool   compare_boundary;             /* Check label I/O via boundary vertex coordinates */
-  PetscBool   compare_pre_post;             /* Compare labels loaded before distribution with those loaded after distribution */
-  char        outfile[PETSC_MAX_PATH_LEN];  /* Output file */
-  PetscBool   use_low_level_functions;      /* Use low level functions for viewing and loading */
+  const char *meshname;                    /* Mesh name */
+  PetscInt    num_labels;                  /* Asserted number of labels in loaded mesh */
+  PetscBool   compare;                     /* Compare the meshes using DMPlexEqual() and DMCompareLabels() */
+  PetscBool   compare_labels;              /* Compare labels in the meshes using DMCompareLabels() */
+  PetscBool   compare_boundary;            /* Check label I/O via boundary vertex coordinates */
+  PetscBool   compare_pre_post;            /* Compare labels loaded before distribution with those loaded after distribution */
+  char        outfile[PETSC_MAX_PATH_LEN]; /* Output file */
+  PetscBool   use_low_level_functions;     /* Use low level functions for viewing and loading */
   //TODO This is meant as temporary option; can be removed once we have full parallel loading in place
-  PetscBool   distribute_after_topo_load;   /* Distribute topology right after DMPlexTopologyLoad(), if use_low_level_functions=true */
-  PetscBool   verbose;
+  PetscBool distribute_after_topo_load; /* Distribute topology right after DMPlexTopologyLoad(), if use_low_level_functions=true */
+  PetscInt  verbose;
 } AppCtx;
 
 static PetscErrorCode ProcessOptions(MPI_Comm comm, AppCtx *options)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBeginUser;
   options->comm                       = comm;
+  options->num_labels                 = -1;
   options->compare                    = PETSC_FALSE;
   options->compare_labels             = PETSC_FALSE;
   options->compare_boundary           = PETSC_FALSE;
@@ -33,9 +31,10 @@ static PetscErrorCode ProcessOptions(MPI_Comm comm, AppCtx *options)
   options->outfile[0]                 = '\0';
   options->use_low_level_functions    = PETSC_FALSE;
   options->distribute_after_topo_load = PETSC_FALSE;
-  options->verbose                    = PETSC_FALSE;
+  options->verbose                    = 0;
 
-  ierr = PetscOptionsBegin(comm, "", "Meshing Problem Options", "DMPLEX");PetscCall(ierr);
+  PetscOptionsBegin(comm, "", "Meshing Problem Options", "DMPLEX");
+  PetscCall(PetscOptionsInt("-num_labels", "Asserted number of labels in meshfile; don't count depth and celltype; -1 to deactivate", EX, options->num_labels, &options->num_labels, NULL));
   PetscCall(PetscOptionsBool("-compare", "Compare the meshes using DMPlexEqual() and DMCompareLabels()", EX, options->compare, &options->compare, NULL));
   PetscCall(PetscOptionsBool("-compare_labels", "Compare labels in the meshes using DMCompareLabels()", "ex55.c", options->compare_labels, &options->compare_labels, NULL));
   PetscCall(PetscOptionsBool("-compare_boundary", "Check label I/O via boundary vertex coordinates", "ex55.c", options->compare_boundary, &options->compare_boundary, NULL));
@@ -43,14 +42,14 @@ static PetscErrorCode ProcessOptions(MPI_Comm comm, AppCtx *options)
   PetscCall(PetscOptionsString("-outfile", "Output mesh file", EX, options->outfile, options->outfile, sizeof(options->outfile), NULL));
   PetscCall(PetscOptionsBool("-use_low_level_functions", "Use low level functions for viewing and loading", EX, options->use_low_level_functions, &options->use_low_level_functions, NULL));
   PetscCall(PetscOptionsBool("-distribute_after_topo_load", "Distribute topology right after DMPlexTopologyLoad(), if use_low_level_functions=true", EX, options->distribute_after_topo_load, &options->distribute_after_topo_load, NULL));
-  PetscCall(PetscOptionsBool("-verbose", "Verbose printing", EX, options->verbose, &options->verbose, NULL));
-  ierr = PetscOptionsEnd();PetscCall(ierr);
-  PetscFunctionReturn(0);
+  PetscCall(PetscOptionsInt("-verbose", "Verbosity level", EX, options->verbose, &options->verbose, NULL));
+  PetscOptionsEnd();
+  PetscFunctionReturn(PETSC_SUCCESS);
 };
 
 static PetscErrorCode CreateMesh(AppCtx *options, DM *newdm)
 {
-  DM             dm;
+  DM dm;
 
   PetscFunctionBeginUser;
   PetscCall(DMCreate(options->comm, &dm));
@@ -59,15 +58,15 @@ static PetscErrorCode CreateMesh(AppCtx *options, DM *newdm)
   PetscCall(PetscObjectGetName((PetscObject)dm, &options->meshname));
   PetscCall(DMViewFromOptions(dm, NULL, "-dm_view"));
   *newdm = dm;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SaveMesh(AppCtx *options, DM dm)
 {
-  PetscViewer    v;
+  PetscViewer v;
 
   PetscFunctionBeginUser;
-  PetscCall(PetscViewerHDF5Open(PetscObjectComm((PetscObject) dm), options->outfile, FILE_MODE_WRITE, &v));
+  PetscCall(PetscViewerHDF5Open(PetscObjectComm((PetscObject)dm), options->outfile, FILE_MODE_WRITE, &v));
   if (options->use_low_level_functions) {
     PetscCall(DMPlexTopologyView(dm, v));
     PetscCall(DMPlexCoordinatesView(dm, v));
@@ -76,20 +75,24 @@ static PetscErrorCode SaveMesh(AppCtx *options, DM dm)
     PetscCall(DMView(dm, v));
   }
   PetscCall(PetscViewerDestroy(&v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-typedef enum {NONE=0, PRE_DIST=1, POST_DIST=2} AuxObjLoadMode;
+typedef enum {
+  NONE      = 0,
+  PRE_DIST  = 1,
+  POST_DIST = 2
+} AuxObjLoadMode;
 
 static PetscErrorCode LoadMeshLowLevel(AppCtx *options, PetscViewer v, PetscBool explicitDistribute, AuxObjLoadMode mode, DM *newdm)
 {
-  DM              dm;
-  PetscSF         sfXC;
+  DM      dm;
+  PetscSF sfXC;
 
   PetscFunctionBeginUser;
   PetscCall(DMCreate(options->comm, &dm));
   PetscCall(DMSetType(dm, DMPLEX));
-  PetscCall(PetscObjectSetName((PetscObject) dm, options->meshname));
+  PetscCall(PetscObjectSetName((PetscObject)dm, options->meshname));
   PetscCall(DMPlexTopologyLoad(dm, v, &sfXC));
   if (mode == PRE_DIST) {
     PetscCall(DMPlexCoordinatesLoad(dm, v, sfXC));
@@ -103,28 +106,28 @@ static PetscErrorCode LoadMeshLowLevel(AppCtx *options, PetscViewer v, PetscBool
     if (dmdist) {
       const char *name;
 
-      PetscCall(PetscObjectGetName((PetscObject) dm, &name));
-      PetscCall(PetscObjectSetName((PetscObject) dmdist, name));
+      PetscCall(PetscObjectGetName((PetscObject)dm, &name));
+      PetscCall(PetscObjectSetName((PetscObject)dmdist, name));
       PetscCall(PetscSFCompose(sfXB, sfBC, &sfXC));
       PetscCall(PetscSFDestroy(&sfXB));
       PetscCall(PetscSFDestroy(&sfBC));
       PetscCall(DMDestroy(&dm));
-      dm   = dmdist;
+      dm = dmdist;
     }
   }
   if (mode == POST_DIST) {
-    PetscCall(DMPlexCoordinatesLoad(dm, v, sfXC));
     PetscCall(DMPlexLabelsLoad(dm, v, sfXC));
+    PetscCall(DMPlexCoordinatesLoad(dm, v, sfXC));
   }
   PetscCall(PetscSFDestroy(&sfXC));
   *newdm = dm;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode LoadMesh(AppCtx *options, DM *dmnew)
 {
-  DM             dm;
-  PetscViewer    v;
+  DM          dm;
+  PetscViewer v;
 
   PetscFunctionBeginUser;
   PetscCall(PetscViewerHDF5Open(options->comm, options->outfile, FILE_MODE_READ, &v));
@@ -142,7 +145,7 @@ static PetscErrorCode LoadMesh(AppCtx *options, DM *dmnew)
   } else {
     PetscCall(DMCreate(options->comm, &dm));
     PetscCall(DMSetType(dm, DMPLEX));
-    PetscCall(PetscObjectSetName((PetscObject) dm, options->meshname));
+    PetscCall(PetscObjectSetName((PetscObject)dm, options->meshname));
     PetscCall(DMLoad(dm, v));
   }
   PetscCall(PetscViewerDestroy(&v));
@@ -151,61 +154,65 @@ static PetscErrorCode LoadMesh(AppCtx *options, DM *dmnew)
   PetscCall(DMSetFromOptions(dm));
   PetscCall(DMViewFromOptions(dm, NULL, "-dm_view"));
   *dmnew = dm;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode CompareMeshes(AppCtx *options, DM dm0, DM dm1)
 {
-  PetscBool       flg;
+  PetscBool flg;
 
   PetscFunctionBeginUser;
   if (options->compare) {
     PetscCall(DMPlexEqual(dm0, dm1, &flg));
-    PetscCheck(flg,options->comm, PETSC_ERR_ARG_INCOMP, "DMs are not equal");
-    PetscCall(PetscPrintf(options->comm,"DMs equal\n"));
+    PetscCheck(flg, options->comm, PETSC_ERR_ARG_INCOMP, "DMs are not equal");
+    PetscCall(PetscPrintf(options->comm, "DMs equal\n"));
   }
   if (options->compare_labels) {
     PetscCall(DMCompareLabels(dm0, dm1, NULL, NULL));
-    PetscCall(PetscPrintf(options->comm,"DMLabels equal\n"));
+    PetscCall(PetscPrintf(options->comm, "DMLabels equal\n"));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode MarkBoundaryVertices(DM dm, PetscInt value, DMLabel *label)
+static PetscErrorCode MarkBoundary(DM dm, const char name[], PetscInt value, PetscBool verticesOnly, DMLabel *label)
 {
-  DMLabel         l;
-  IS              points;
-  const PetscInt *idx;
-  PetscInt        i, n;
+  DMLabel l;
 
   PetscFunctionBeginUser;
-  PetscCall(DMLabelCreate(PetscObjectComm((PetscObject)dm), LABEL_NAME, &l));
+  PetscCall(DMLabelCreate(PetscObjectComm((PetscObject)dm), name, &l));
+  PetscCall(DMAddLabel(dm, l));
   PetscCall(DMPlexMarkBoundaryFaces(dm, value, l));
   PetscCall(DMPlexLabelComplete(dm, l));
-  PetscCall(DMLabelGetStratumIS(l, value, &points));
+  if (verticesOnly) {
+    IS              points;
+    const PetscInt *idx;
+    PetscInt        i, n = 0;
 
-  PetscCall(ISGetLocalSize(points, &n));
-  PetscCall(ISGetIndices(points, &idx));
-  for (i=0; i<n; i++) {
-    const PetscInt p = idx[i];
-    PetscInt       d;
-
-    PetscCall(DMPlexGetPointDepth(dm, p, &d));
-    if (d != 0) {
-      PetscCall(DMLabelClearValue(l, p, value));
+    PetscCall(DMLabelGetStratumIS(l, value, &points));
+    if (points) {
+      PetscCall(ISGetLocalSize(points, &n));
+      PetscCall(ISGetIndices(points, &idx));
     }
+    for (i = 0; i < n; i++) {
+      const PetscInt p = idx[i];
+      PetscInt       d;
+
+      PetscCall(DMPlexGetPointDepth(dm, p, &d));
+      if (d != 0) PetscCall(DMLabelClearValue(l, p, value));
+    }
+    if (points) PetscCall(ISRestoreIndices(points, &idx));
+    PetscCall(ISDestroy(&points));
   }
-  PetscCall(ISRestoreIndices(points, &idx));
-  PetscCall(ISDestroy(&points));
-  *label = l;
-  PetscFunctionReturn(0);
+  if (label) *label = l;
+  else PetscCall(DMLabelDestroy(&l));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VertexCoordinatesToAll(DM dm, IS vertices, Vec *allCoords)
 {
-  Vec             coords, allCoords_;
-  VecScatter      sc;
-  MPI_Comm        comm;
+  Vec        coords, allCoords_;
+  VecScatter sc;
+  MPI_Comm   comm;
 
   PetscFunctionBeginUser;
   PetscCall(PetscObjectGetComm((PetscObject)dm, &comm));
@@ -213,47 +220,42 @@ static PetscErrorCode VertexCoordinatesToAll(DM dm, IS vertices, Vec *allCoords)
   if (vertices) {
     PetscCall(DMGetCoordinatesLocalTuple(dm, vertices, NULL, &coords));
   } else {
-    PetscCall(VecCreateSeq(PETSC_COMM_SELF, 0, &coords));
+    PetscCall(VecCreateFromOptions(PETSC_COMM_SELF, NULL, 1, 0, 0, &coords));
   }
   {
-    PetscInt  n;
-    Vec       mpivec;
+    PetscInt n;
+    Vec      mpivec;
 
     PetscCall(VecGetLocalSize(coords, &n));
-    PetscCall(VecCreateMPI(comm, n, PETSC_DECIDE, &mpivec));
+    PetscCall(VecCreateFromOptions(comm, NULL, 1, n, PETSC_DECIDE, &mpivec));
     PetscCall(VecCopy(coords, mpivec));
     PetscCall(VecDestroy(&coords));
     coords = mpivec;
   }
 
   PetscCall(VecScatterCreateToAll(coords, &sc, &allCoords_));
-  PetscCall(VecScatterBegin(sc,coords,allCoords_,INSERT_VALUES,SCATTER_FORWARD));
-  PetscCall(VecScatterEnd(sc,coords,allCoords_,INSERT_VALUES,SCATTER_FORWARD));
+  PetscCall(VecScatterBegin(sc, coords, allCoords_, INSERT_VALUES, SCATTER_FORWARD));
+  PetscCall(VecScatterEnd(sc, coords, allCoords_, INSERT_VALUES, SCATTER_FORWARD));
   PetscCall(VecScatterDestroy(&sc));
   PetscCall(VecDestroy(&coords));
   *allCoords = allCoords_;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* Compute boundary label, remember boundary vertices using coordinates, save and load label, check it is defined on the original boundary vertices */
-static PetscErrorCode DMAddBoundaryLabel_GetCoordinateRepresentation(DM dm, Vec *allCoords)
+static PetscErrorCode DMLabelGetCoordinateRepresentation(DM dm, DMLabel label, PetscInt value, Vec *allCoords)
 {
-  DMLabel         label;
-  IS              vertices;
+  IS vertices;
 
   PetscFunctionBeginUser;
-  PetscCall(MarkBoundaryVertices(dm, LABEL_VALUE, &label));
-  PetscCall(DMLabelGetStratumIS(label, LABEL_VALUE, &vertices));
+  PetscCall(DMLabelGetStratumIS(label, value, &vertices));
   PetscCall(VertexCoordinatesToAll(dm, vertices, allCoords));
-  PetscCall(DMAddLabel(dm, label));
-  PetscCall(DMLabelDestroy(&label));
   PetscCall(ISDestroy(&vertices));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode DMGetBoundaryLabel_CompareWithCoordinateRepresentation(AppCtx *user, DM dm, Vec allCoords)
+static PetscErrorCode DMLabelCompareWithCoordinateRepresentation(DM dm, DMLabel label, PetscInt value, Vec allCoords, PetscInt verbose)
 {
-  DMLabel         label;
+  const char     *labelName;
   IS              pointsIS;
   const PetscInt *points;
   PetscInt        i, n;
@@ -262,10 +264,10 @@ static PetscErrorCode DMGetBoundaryLabel_CompareWithCoordinateRepresentation(App
   PetscMPIInt     rank;
 
   PetscFunctionBeginUser;
+  PetscCheck(label, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Label not loaded");
   PetscCall(PetscObjectGetComm((PetscObject)dm, &comm));
+  PetscCall(PetscObjectGetName((PetscObject)label, &labelName));
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
-  PetscCall(DMGetLabel(dm, LABEL_NAME, &label));
-  PetscCheck(label,PETSC_COMM_SELF, PETSC_ERR_PLIB, "Label \"%s\" was not loaded", LABEL_NAME);
   {
     PetscInt pStart, pEnd;
 
@@ -275,53 +277,113 @@ static PetscErrorCode DMGetBoundaryLabel_CompareWithCoordinateRepresentation(App
   PetscCall(DMPlexFindVertices(dm, allCoords, 0.0, &pointsIS));
   PetscCall(ISGetIndices(pointsIS, &points));
   PetscCall(ISGetLocalSize(pointsIS, &n));
-  if (user->verbose) PetscCall(DMLabelView(label, PETSC_VIEWER_STDOUT_(comm)));
-  for (i=0; i<n; i++) {
-    const PetscInt  p = points[i];
-    PetscBool       has;
-    PetscInt        v;
+  if (verbose > 1) PetscCall(DMLabelView(label, PETSC_VIEWER_STDOUT_(comm)));
+  for (i = 0; i < n; i++) {
+    const PetscInt p = points[i];
+    PetscBool      has;
+    PetscInt       v;
 
     if (p < 0) continue;
     PetscCall(DMLabelHasPoint(label, p, &has));
     if (!has) {
-      PetscCall(PetscSynchronizedFPrintf(comm, PETSC_STDERR, "[%d] Label does not have point %D\n", rank, p));
+      if (verbose) PetscCall(PetscSynchronizedFPrintf(comm, PETSC_STDERR, "[%d] Label \"%s\" does not have point %" PetscInt_FMT "\n", rank, labelName, p));
       fail = PETSC_TRUE;
       continue;
     }
     PetscCall(DMLabelGetValue(label, p, &v));
-    if (v != LABEL_VALUE) {
-      PetscCall(PetscSynchronizedFPrintf(comm, PETSC_STDERR, "Point %D has bad value %D", p, v));
+    if (v != value) {
+      if (verbose) PetscCall(PetscSynchronizedFPrintf(comm, PETSC_STDERR, "Point %" PetscInt_FMT " has bad value %" PetscInt_FMT " in label \"%s\"", p, v, labelName));
       fail = PETSC_TRUE;
       continue;
     }
-    if (user->verbose) PetscCall(PetscSynchronizedPrintf(comm, "[%d] OK point %D\n", rank, p));
+    if (verbose > 1) PetscCall(PetscSynchronizedPrintf(comm, "[%d] OK point %" PetscInt_FMT "\n", rank, p));
   }
   PetscCall(PetscSynchronizedFlush(comm, PETSC_STDOUT));
   PetscCall(PetscSynchronizedFlush(comm, PETSC_STDERR));
   PetscCall(ISRestoreIndices(pointsIS, &points));
   PetscCall(ISDestroy(&pointsIS));
-  PetscCallMPI(MPI_Allreduce(MPI_IN_PLACE, &fail, 1, MPIU_BOOL, MPI_LOR, comm));
-  PetscCheck(!fail,comm, PETSC_ERR_PLIB, "Label \"%s\" was not loaded correctly - see details above", LABEL_NAME);
-  PetscFunctionReturn(0);
+  PetscCall(MPIU_Allreduce(MPI_IN_PLACE, &fail, 1, MPIU_BOOL, MPI_LOR, comm));
+  PetscCheck(!fail, comm, PETSC_ERR_PLIB, "Label \"%s\" was not loaded correctly%s", labelName, verbose ? " - see details above" : "");
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+static PetscErrorCode CheckNumLabels(DM dm, AppCtx *ctx)
+{
+  PetscInt    actualNum;
+  PetscBool   fail = PETSC_FALSE;
+  MPI_Comm    comm;
+  PetscMPIInt rank;
+
+  PetscFunctionBeginUser;
+  if (ctx->num_labels < 0) PetscFunctionReturn(PETSC_SUCCESS);
+  PetscCall(PetscObjectGetComm((PetscObject)dm, &comm));
+  PetscCallMPI(MPI_Comm_rank(comm, &rank));
+  PetscCall(DMGetNumLabels(dm, &actualNum));
+  if (ctx->num_labels != actualNum) {
+    fail = PETSC_TRUE;
+    if (ctx->verbose) {
+      PetscInt i;
+
+      PetscCall(PetscSynchronizedFPrintf(comm, PETSC_STDERR, "[%d] Asserted number of labels: %" PetscInt_FMT ", actual: %" PetscInt_FMT "\n", rank, ctx->num_labels, actualNum));
+      for (i = 0; i < actualNum; i++) {
+        DMLabel     label;
+        const char *name;
+
+        PetscCall(DMGetLabelByNum(dm, i, &label));
+        PetscCall(PetscObjectGetName((PetscObject)label, &name));
+        PetscCall(PetscSynchronizedFPrintf(comm, PETSC_STDERR, "[%d] Label %" PetscInt_FMT " \"%s\"\n", rank, i, name));
+      }
+      PetscCall(PetscSynchronizedFlush(comm, PETSC_STDERR));
+    }
+  }
+  PetscCall(MPIU_Allreduce(MPI_IN_PLACE, &fail, 1, MPIU_BOOL, MPI_LOR, comm));
+  PetscCheck(!fail, comm, PETSC_ERR_PLIB, "Wrong number of labels%s", ctx->verbose ? " - see details above" : "");
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+static inline PetscErrorCode IncrementNumLabels(AppCtx *ctx)
+{
+  PetscFunctionBeginUser;
+  if (ctx->num_labels >= 0) ctx->num_labels++;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 int main(int argc, char **argv)
 {
+  const char     BOUNDARY_NAME[]          = "Boundary";
+  const char     BOUNDARY_VERTICES_NAME[] = "BoundaryVertices";
+  const PetscInt BOUNDARY_VALUE           = 12345;
+  const PetscInt BOUNDARY_VERTICES_VALUE  = 6789;
   DM             dm, dmnew;
   AppCtx         user;
   Vec            allCoords = NULL;
 
+  PetscFunctionBeginUser;
   PetscCall(PetscInitialize(&argc, &argv, NULL, help));
   PetscCall(ProcessOptions(PETSC_COMM_WORLD, &user));
   PetscCall(CreateMesh(&user, &dm));
+  PetscCall(MarkBoundary(dm, BOUNDARY_NAME, BOUNDARY_VALUE, PETSC_FALSE, NULL));
+  PetscCall(IncrementNumLabels(&user));
   if (user.compare_boundary) {
-    PetscCall(DMAddBoundaryLabel_GetCoordinateRepresentation(dm, &allCoords));
+    DMLabel label;
+
+    PetscCall(MarkBoundary(dm, BOUNDARY_VERTICES_NAME, BOUNDARY_VERTICES_VALUE, PETSC_TRUE, &label));
+    PetscCall(IncrementNumLabels(&user));
+    PetscCall(DMLabelGetCoordinateRepresentation(dm, label, BOUNDARY_VERTICES_VALUE, &allCoords));
+    PetscCall(DMLabelDestroy(&label));
   }
   PetscCall(SaveMesh(&user, dm));
+
   PetscCall(LoadMesh(&user, &dmnew));
+  PetscCall(IncrementNumLabels(&user)); /* account for depth label */
+  PetscCall(IncrementNumLabels(&user)); /* account for celltype label */
+  PetscCall(CheckNumLabels(dm, &user));
   PetscCall(CompareMeshes(&user, dm, dmnew));
   if (user.compare_boundary) {
-    PetscCall(DMGetBoundaryLabel_CompareWithCoordinateRepresentation(&user, dmnew, allCoords));
+    DMLabel label;
+
+    PetscCall(DMGetLabel(dmnew, BOUNDARY_VERTICES_NAME, &label));
+    PetscCall(DMLabelCompareWithCoordinateRepresentation(dmnew, label, BOUNDARY_VERTICES_VALUE, allCoords, user.verbose));
   }
   PetscCall(DMDestroy(&dm));
   PetscCall(DMDestroy(&dmnew));
@@ -341,9 +403,10 @@ int main(int argc, char **argv)
     requires: !complex datafilespath
     args: -dm_plex_name plex
     args: -dm_plex_check_all -dm_plex_view_hdf5_storage_version 2.0.0
-    args: -dm_plex_interpolate
+    args: -dm_plex_interpolate -petscpartitioner_type simple
     args: -load_dm_plex_check_all
     args: -use_low_level_functions {{0 1}} -compare_boundary
+    args: -num_labels 1
     args: -outfile ex56_1.h5
     nsize: {{1 3}}
     test:
@@ -358,7 +421,7 @@ int main(int argc, char **argv)
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/blockcylinder-50.h5
     test:
       suffix: d
-      args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/cube-hexahedra-refined.h5
+      args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/cube-hexahedra-refined.h5 -num_labels 0
     test:
       suffix: e
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/hybrid_hexwedge.h5
@@ -372,9 +435,10 @@ int main(int argc, char **argv)
     requires: !complex datafilespath
     args: -dm_plex_name plex
     args: -dm_plex_check_all -dm_plex_view_hdf5_storage_version 2.0.0
-    args: -dm_plex_interpolate
+    args: -dm_plex_interpolate -petscpartitioner_type simple
     args: -load_dm_plex_check_all
     args: -use_low_level_functions -load_dm_distribute 0 -distribute_after_topo_load -compare_boundary
+    args: -num_labels 1
     args: -outfile ex56_2.h5
     nsize: 3
     test:
@@ -389,7 +453,7 @@ int main(int argc, char **argv)
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/blockcylinder-50.h5
     test:
       suffix: d
-      args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/cube-hexahedra-refined.h5
+      args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/cube-hexahedra-refined.h5 -num_labels 0
     test:
       suffix: e
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/hybrid_hexwedge.h5
@@ -403,8 +467,9 @@ int main(int argc, char **argv)
     requires: !complex datafilespath
     args: -dm_plex_name plex
     args: -dm_plex_view_hdf5_storage_version 2.0.0
-    args: -dm_plex_interpolate -load_dm_distribute 0
+    args: -dm_plex_interpolate -load_dm_distribute 0 -petscpartitioner_type simple
     args: -use_low_level_functions -compare_pre_post
+    args: -num_labels 1
     args: -outfile ex56_3.h5
     nsize: 3
     test:
@@ -419,7 +484,7 @@ int main(int argc, char **argv)
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/blockcylinder-50.h5
     test:
       suffix: d
-      args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/cube-hexahedra-refined.h5
+      args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/cube-hexahedra-refined.h5 -num_labels 0
     test:
       suffix: e
       args: -dm_plex_filename ${DATAFILESPATH}/meshes/hdf5-petsc/petsc-v3.16.0/v1.0.0/hybrid_hexwedge.h5
