@@ -1,4 +1,3 @@
-
 #include <../src/ksp/ksp/impls/cg/gltr/gltrimpl.h> /*I "petscksp.h" I*/
 #include <petscblaslapack.h>
 
@@ -9,19 +8,19 @@
 static const char *DType_Table[64] = {"preconditioned", "unpreconditioned"};
 
 /*@
-    KSPGLTRGetMinEig - Get minimum eigenvalue computed by `KSPGLTR`
+  KSPGLTRGetMinEig - Get minimum eigenvalue computed by `KSPGLTR`
 
-    Collective
+  Collective
 
-    Input Parameter:
-.   ksp   - the iterative context
+  Input Parameter:
+. ksp - the iterative context
 
-    Output Parameter:
-.   e_min - the minimum eigenvalue
+  Output Parameter:
+. e_min - the minimum eigenvalue
 
-    Level: advanced
+  Level: advanced
 
-.seealso: [](chapter_ksp), `KSPGLTR`, `KSPGLTRGetLambda()`
+.seealso: [](ch_ksp), `KSPGLTR`, `KSPGLTRGetLambda()`
 @*/
 PetscErrorCode KSPGLTRGetMinEig(KSP ksp, PetscReal *e_min)
 {
@@ -32,19 +31,19 @@ PetscErrorCode KSPGLTRGetMinEig(KSP ksp, PetscReal *e_min)
 }
 
 /*@
-    KSPGLTRGetLambda - Get the multiplier on the trust-region constraint when using `KSPGLTR`
-t
-    Not Collective
+  KSPGLTRGetLambda - Get the multiplier on the trust-region constraint when using `KSPGLTR`
+  t
+  Not Collective
 
-    Input Parameter:
-.   ksp    - the iterative context
+  Input Parameter:
+. ksp - the iterative context
 
-    Output Parameter:
-.   lambda - the multiplier
+  Output Parameter:
+. lambda - the multiplier
 
-    Level: advanced
+  Level: advanced
 
-.seealso: [](chapter_ksp), `KSPGLTR`, `KSPGLTRGetMinEig()`
+.seealso: [](ch_ksp), `KSPGLTR`, `KSPGLTRGetMinEig()`
 @*/
 PetscErrorCode KSPGLTRGetLambda(KSP ksp, PetscReal *lambda)
 {
@@ -1329,7 +1328,7 @@ static PetscErrorCode KSPCGSetFromOptions_GLTR(KSP ksp, PetscOptionItems *PetscO
 . * -  Gould, N. and Lucidi, S. and Roma, M. and Toint, P., Solving the Trust-Region Subproblem using the Lanczos Method,
    SIAM Journal on Optimization, volume 9, number 2, 1999, 504-525
 
-.seealso: [](chapter_ksp), `KSPQCG`, `KSPNASH`, `KSPSTCG`, `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPCGSetRadius()`, `KSPCGGetNormD()`, `KSPCGGetObjFcn()`, `KSPGLTRGetMinEig()`, `KSPGLTRGetLambda()`, `KSPCG`
+.seealso: [](ch_ksp), `KSPQCG`, `KSPNASH`, `KSPSTCG`, `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPCGSetRadius()`, `KSPCGGetNormD()`, `KSPCGGetObjFcn()`, `KSPGLTRGetMinEig()`, `KSPGLTRGetLambda()`, `KSPCG`
 M*/
 
 PETSC_EXTERN PetscErrorCode KSPCreate_GLTR(KSP ksp)
