@@ -1,4 +1,3 @@
-
 /*
    Routines to compute overlapping regions of a parallel MPI matrix.
    Used for finding submatrices that were shared across processors.
@@ -27,7 +26,7 @@ PetscErrorCode MatIncreaseOverlap_MPISBAIJ(Mat C, PetscInt is_max, IS is[], Pets
   PetscCall(ISCompressIndicesGeneral(N, C->rmap->n, bs, is_max, is, is_new));
   PetscCheck(ov >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Negative overlap specified");
 
-  /* ----- previous non-scalable implementation ----- */
+  /*  previous non-scalable implementation  */
   flg = PETSC_FALSE;
   PetscCall(PetscOptionsHasName(NULL, NULL, "-IncreaseOverlap_old", &flg));
   if (flg) { /* previous non-scalable implementation */
@@ -55,70 +54,83 @@ PetscErrorCode MatIncreaseOverlap_MPISBAIJ(Mat C, PetscInt is_max, IS is[], Pets
     /* Make sure every processor loops through the nstages */
     PetscCall(MPIU_Allreduce(&nstages_local, &nstages, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)C)));
 
-    for (iov = 0; iov < ov; ++iov) {
-      /* 1) Get submats for column search */
-      for (i = 0, pos = 0; i < nstages; i++) {
-        if (pos + nmax <= is_max) max_no = nmax;
-        else if (pos == is_max) max_no = 0;
-        else max_no = is_max - pos;
-        c->ijonly = PETSC_TRUE; /* only matrix data structures are requested */
-        /* The resulting submatrices should be BAIJ, not SBAIJ, hence we change this value to trigger that */
-        PetscCall(PetscStrcpy(((PetscObject)c->A)->type_name, MATSEQBAIJ));
-        PetscCall(MatCreateSubMatrices_MPIBAIJ_local(C, max_no, is_row + pos, is_new + pos, MAT_INITIAL_MATRIX, submats + pos));
-        PetscCall(PetscStrcpy(((PetscObject)c->A)->type_name, MATSEQSBAIJ));
-        pos += max_no;
-      }
+    {
+      const PetscObject obj = (PetscObject)c->A;
+      size_t            new_len, cur_len, max_len;
 
-      /* 2) Row search */
-      PetscCall(MatIncreaseOverlap_MPIBAIJ_Once(C, is_max, is_new));
+      PetscCall(PetscStrlen(MATSEQBAIJ, &new_len));
+      PetscCall(PetscStrlen(MATSEQSBAIJ, &cur_len));
+      max_len = PetscMax(cur_len, new_len) + 1;
+      PetscCall(PetscRealloc(max_len * sizeof(*(obj->type_name)), &obj->type_name));
+      /* The resulting submatrices should be BAIJ, not SBAIJ, hence we change this value to
+         trigger that */
+      for (iov = 0; iov < ov; ++iov) {
+        /* 1) Get submats for column search */
+        PetscCall(PetscStrncpy(obj->type_name, MATSEQBAIJ, max_len));
+        for (i = 0, pos = 0; i < nstages; i++) {
+          if (pos + nmax <= is_max) max_no = nmax;
+          else if (pos == is_max) max_no = 0;
+          else max_no = is_max - pos;
+          c->ijonly = PETSC_TRUE; /* only matrix data structures are requested */
 
-      /* 3) Column search */
-      for (i = 0; i < is_max; i++) {
-        asub_i = (Mat_SeqSBAIJ *)submats[i]->data;
-        ai     = asub_i->i;
-
-        /* put is_new obtained from MatIncreaseOverlap_MPIBAIJ() to table */
-        PetscCall(PetscBTMemzero(Mbs, table));
-
-        PetscCall(ISGetIndices(is_new[i], &idx));
-        PetscCall(ISGetLocalSize(is_new[i], &nis));
-        for (l = 0; l < nis; l++) {
-          PetscCall(PetscBTSet(table, idx[l]));
-          nidx[l] = idx[l];
+          PetscCall(MatCreateSubMatrices_MPIBAIJ_local(C, max_no, is_row + pos, is_new + pos, MAT_INITIAL_MATRIX, submats + pos, PETSC_TRUE));
+          pos += max_no;
         }
-        isz = nis;
+        PetscCall(PetscStrncpy(obj->type_name, MATSEQSBAIJ, max_len));
 
-        /* add column entries to table */
-        for (brow = 0; brow < Mbs; brow++) {
-          nz = ai[brow + 1] - ai[brow];
-          if (nz) {
-            if (!PetscBTLookupSet(table, brow)) nidx[isz++] = brow;
+        /* 2) Row search */
+        PetscCall(MatIncreaseOverlap_MPIBAIJ_Once(C, is_max, is_new));
+
+        /* 3) Column search */
+        for (i = 0; i < is_max; i++) {
+          asub_i = (Mat_SeqSBAIJ *)submats[i]->data;
+          ai     = asub_i->i;
+
+          /* put is_new obtained from MatIncreaseOverlap_MPIBAIJ() to table */
+          PetscCall(PetscBTMemzero(Mbs, table));
+
+          PetscCall(ISGetIndices(is_new[i], &idx));
+          PetscCall(ISGetLocalSize(is_new[i], &nis));
+          for (l = 0; l < nis; l++) {
+            PetscCall(PetscBTSet(table, idx[l]));
+            nidx[l] = idx[l];
           }
-        }
-        PetscCall(ISRestoreIndices(is_new[i], &idx));
-        PetscCall(ISDestroy(&is_new[i]));
+          isz = nis;
 
-        /* create updated is_new */
-        PetscCall(ISCreateGeneral(PETSC_COMM_SELF, isz, nidx, PETSC_COPY_VALUES, is_new + i));
+          /* add column entries to table */
+          for (brow = 0; brow < Mbs; brow++) {
+            nz = ai[brow + 1] - ai[brow];
+            if (nz) {
+              if (!PetscBTLookupSet(table, brow)) nidx[isz++] = brow;
+            }
+          }
+          PetscCall(ISRestoreIndices(is_new[i], &idx));
+          PetscCall(ISDestroy(&is_new[i]));
+
+          /* create updated is_new */
+          PetscCall(ISCreateGeneral(PETSC_COMM_SELF, isz, nidx, PETSC_COPY_VALUES, is_new + i));
+        }
+
+        /* Free tmp spaces */
+        for (i = 0; i < is_max; i++) PetscCall(MatDestroy(&submats[i]));
       }
 
-      /* Free tmp spaces */
-      for (i = 0; i < is_max; i++) PetscCall(MatDestroy(&submats[i]));
+      PetscCall(PetscBTDestroy(&table));
+      PetscCall(PetscFree(submats));
+      PetscCall(ISDestroy(&is_row[0]));
+      PetscCall(PetscFree(is_row));
+      PetscCall(PetscFree(nidx));
     }
-
-    PetscCall(PetscBTDestroy(&table));
-    PetscCall(PetscFree(submats));
-    PetscCall(ISDestroy(&is_row[0]));
-    PetscCall(PetscFree(is_row));
-    PetscCall(PetscFree(nidx));
   }
-
-  for (i = 0; i < is_max; i++) PetscCall(ISDestroy(&is[i]));
-  PetscCall(ISExpandIndicesGeneral(N, N, bs, is_max, is_new, is));
-
-  for (i = 0; i < is_max; i++) PetscCall(ISDestroy(&is_new[i]));
+  for (i = 0; i < is_max; i++) {
+    PetscCall(ISDestroy(&is[i]));
+    PetscCall(ISGetLocalSize(is_new[i], &nis));
+    PetscCall(ISGetIndices(is_new[i], &idx));
+    PetscCall(ISCreateBlock(PetscObjectComm((PetscObject)is_new[i]), bs, nis, idx, PETSC_COPY_VALUES, &is[i]));
+    PetscCall(ISDestroy(&is_new[i]));
+  }
   PetscCall(PetscFree(is_new));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 typedef enum {
@@ -184,7 +196,6 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C, PetscInt is_max, I
   PetscCall(MPIU_Allreduce(&is_max, &ois_max, 1, MPIU_INT, MPI_MAX, comm));
 
   /* 1. Send this processor's is[] to other processors */
-  /*---------------------------------------------------*/
   /* allocate spaces */
   PetscCall(PetscMalloc1(is_max, &n));
   len = 0;
@@ -256,7 +267,7 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C, PetscInt is_max, I
     for (j = 0; j < n[i]; j++) {
       idx                = idx_i[j];
       *data1_start[rank] = idx;
-      data1_start[rank]++; /* for local proccessing */
+      data1_start[rank]++; /* for local processing */
       proc_end = ctable[idx];
       for (proc_id = 0; proc_id <= proc_end; proc_id++) {                        /* for others to process */
         if (proc_id == rank) continue;                                           /* done before this loop */
@@ -304,7 +315,6 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C, PetscInt is_max, I
   }
 
   /* 2. Receive other's is[] and process. Then send back */
-  /*-----------------------------------------------------*/
   len = 0;
   for (i = 0; i < nrqr; i++) {
     if (len_r1[i] > len) len = len_r1[i];
@@ -363,7 +373,6 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C, PetscInt is_max, I
   PetscCall(PetscBTDestroy(&otable));
 
   /* 3. Do local work on this processor's is[] */
-  /*-------------------------------------------*/
   /* make sure there is enough unused space in odata2(=data) array */
   len_max = is_max * (Mbs + 1); /* max space storing all is[] for this processor */
   if (len_unused < len_max) {   /* allocate more space for odata2 */
@@ -377,7 +386,6 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C, PetscInt is_max, I
   PetscCall(PetscFree(data1_start));
 
   /* 4. Receive work done on other processors, then merge */
-  /*------------------------------------------------------*/
   /* get max number of messages that this processor expects to recv */
   PetscCall(MPIU_Allreduce(len_s, iwork, size, MPI_INT, MPI_MAX, comm));
   PetscCall(PetscMalloc1(iwork[rank] + 1, &data2));
@@ -425,14 +433,13 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Once(Mat C, PetscInt is_max, I
   PetscCall(PetscFree(s_status));
 
   /* 5. Create new is[] */
-  /*--------------------*/
   for (i = 0; i < is_max; i++) {
     data_i = data + 1 + is_max + Mbs * i;
     PetscCall(ISCreateGeneral(PETSC_COMM_SELF, data[1 + i], data_i, PETSC_COPY_VALUES, is + i));
   }
   for (k = 0; k <= nodata2; k++) PetscCall(PetscFree(odata2_ptr[k]));
   PetscCall(PetscFree(odata2_ptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -461,7 +468,7 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat C, PetscInt *data, P
   PetscInt      row, mbs, Mbs, *nidx_i, col, col_max, isz, isz0, *ai, *aj, *bi, *bj, *garray, rstart, l;
   PetscInt      a_start, a_end, b_start, b_end, i, j, k, is_max, *idx_i, n;
   PetscBT       table0;  /* mark the indices of input is[] for look up */
-  PetscBT       table_i; /* poits to i-th table. When whose=OTHER, a single table is used for all is[] */
+  PetscBT       table_i; /* points to i-th table. When whose=OTHER, a single table is used for all is[] */
 
   PetscFunctionBegin;
   Mbs    = c->Mbs;
@@ -530,7 +537,7 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat C, PetscInt *data, P
         k++;
         if (k >= isz0) break;               /* for (row=0; row<mbs; row++) */
       } else {                              /* row is not on input is[i]:
-                  do col serach: add row onto nidx_i if there is a col in nidx_i */
+                  do col search: add row onto nidx_i if there is a col in nidx_i */
         for (l = a_start; l < a_end; l++) { /* Amat */
           col = aj[l] + rstart;
           if (col > col_max) break;
@@ -557,5 +564,5 @@ static PetscErrorCode MatIncreaseOverlap_MPISBAIJ_Local(Mat C, PetscInt *data, P
     nidx[1 + i] = isz; /* size of new is[i] */
   }                    /* for each is */
   PetscCall(PetscBTDestroy(&table0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
