@@ -17,22 +17,23 @@ static PetscErrorCode PetscBagRegister_Private(PetscBag bag, PetscBagItem item,
     nitem->next = item;
   } else bag->bagitems = item;
   bag->count++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterEnum - add an enum value to a `PetscBag`
+  PetscBagRegisterEnum - add an enum value to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of enum in struct, for example `&params->dt`
-.  list - array of strings containing names of enum values followed by enum name followed by enum prefix
-.  mdefault - the initial value, cast with (`PetscEnum`)
--  help - longer string with more information about the value
+  Input Parameters:
++ bag      - the bag of values
+. addr     - location of enum in struct, for example `&params->dt`
+. list     - array of strings containing names of enum values followed by enum name followed by enum prefix
+. mdefault - the initial value, cast with (`PetscEnum`)
+. name     - the name of the item
+- help     - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -46,11 +47,11 @@ PetscErrorCode PetscBagRegisterEnum(PetscBag bag, void *addr, const char *const
   PetscInt     i = 0;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidPointer(list, 3);
-  PetscValidCharPointer(name, 5);
-  PetscValidCharPointer(help, 6);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(list, 3);
+  PetscAssertPointer(name, 5);
+  PetscAssertPointer(help, 6);
   nname[0] = '-';
   nname[1] = 0;
   PetscCall(PetscStrlcat(nname, name, PETSC_BAG_NAME_LENGTH));
@@ -73,22 +74,22 @@ PetscErrorCode PetscBagRegisterEnum(PetscBag bag, void *addr, const char *const
   PetscCall(PetscStrArrayallocpy(list, (char ***)&item->list));
   *(PetscEnum *)addr = mdefault;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterIntArray - add an `PetscInt` array to a `PetscBag`
+  PetscBagRegisterIntArray - add a `PetscInt` array to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of integer in struct, for example `&params->i`
-.  msize - number of entries in array
-.  name - name of the array
--  help - longer string with more information about the value
+  Input Parameters:
++ bag   - the bag of values
+. addr  - location of integer in struct, for example `&params->i`
+. msize - number of entries in array
+. name  - name of the array
+- help  - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -102,10 +103,10 @@ PetscErrorCode PetscBagRegisterIntArray(PetscBag bag, void *addr, PetscInt msize
   PetscInt     i, tmp = msize;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidCharPointer(name, 4);
-  PetscValidCharPointer(help, 5);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(name, 4);
+  PetscAssertPointer(help, 5);
   nname[0] = '-';
   nname[1] = 0;
   PetscCall(PetscStrlcat(nname, name, PETSC_BAG_NAME_LENGTH));
@@ -124,22 +125,22 @@ PetscErrorCode PetscBagRegisterIntArray(PetscBag bag, void *addr, PetscInt msize
   item->next  = NULL;
   item->msize = msize;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterRealArray - add an `PetscReal` array to a `PetscBag`
+  PetscBagRegisterRealArray - add a `PetscReal` array to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of real array in struct, for example `&params->d`
-.  msize - number of entries in the array
-.  name - name of the array
--  help - longer string with more information about the value
+  Input Parameters:
++ bag   - the bag of values
+. addr  - location of real array in struct, for example `&params->d`
+. msize - number of entries in the array
+. name  - name of the array
+- help  - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -153,10 +154,10 @@ PetscErrorCode PetscBagRegisterRealArray(PetscBag bag, void *addr, PetscInt msiz
   PetscInt     i, tmp = msize;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidCharPointer(name, 4);
-  PetscValidCharPointer(help, 5);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(name, 4);
+  PetscAssertPointer(help, 5);
   nname[0] = '-';
   nname[1] = 0;
   PetscCall(PetscStrlcat(nname, name, PETSC_BAG_NAME_LENGTH));
@@ -175,22 +176,22 @@ PetscErrorCode PetscBagRegisterRealArray(PetscBag bag, void *addr, PetscInt msiz
   item->next  = NULL;
   item->msize = msize;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterInt - add an `PetscInt` value to a `PetscBag`
+  PetscBagRegisterInt - add a `PetscInt` value to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of integer in struct, for example `&params->i`
-.  mdefault - the initial value
-.  name - name of the integer
--  help - longer string with more information about the value
+  Input Parameters:
++ bag      - the bag of values
+. addr     - location of integer in struct, for example `&params->i`
+. mdefault - the initial value
+. name     - name of the integer
+- help     - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterInt64()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -203,10 +204,10 @@ PetscErrorCode PetscBagRegisterInt(PetscBag bag, void *addr, PetscInt mdefault,
   PetscBool    printhelp;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidCharPointer(name, 4);
-  PetscValidCharPointer(help, 5);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(name, 4);
+  PetscAssertPointer(help, 5);
   nname[0] = '-';
   nname[1] = 0;
   PetscCall(PetscStrlcat(nname, name, PETSC_BAG_NAME_LENGTH));
@@ -222,22 +223,22 @@ PetscErrorCode PetscBagRegisterInt(PetscBag bag, void *addr, PetscInt mdefault,
   item->msize       = 1;
   *(PetscInt *)addr = mdefault;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterInt64 - add a `PetscInt64` value to a `PetscBag`
+  PetscBagRegisterInt64 - add a `PetscInt64` value to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of integer in struct, for example `&params->i`
-.  mdefault - the initial value
-.  name - name of the integer
--  help - longer string with more information about the value
+  Input Parameters:
++ bag      - the bag of values
+. addr     - location of integer in struct, for example `&params->i`
+. mdefault - the initial value
+. name     - name of the integer
+- help     - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -268,22 +269,22 @@ PetscErrorCode PetscBagRegisterInt64(PetscBag bag, void *addr, PetscInt64 mdefau
   item->msize         = 1;
   *(PetscInt64 *)addr = mdefault;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterBoolArray - add a n `PetscBool` values to a `PetscBag`
+  PetscBagRegisterBoolArray - add a n `PetscBool` values to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of boolean array in struct, for example `&params->b`
-.  msize - number of entries in array
-.  name - name of the boolean array
--  help - longer string with more information about the value
+  Input Parameters:
++ bag   - the bag of values
+. addr  - location of boolean array in struct, for example `&params->b`
+. msize - number of entries in array
+. name  - name of the boolean array
+- help  - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -297,10 +298,10 @@ PetscErrorCode PetscBagRegisterBoolArray(PetscBag bag, void *addr, PetscInt msiz
   PetscInt     i, tmp = msize;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidCharPointer(name, 4);
-  PetscValidCharPointer(help, 5);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(name, 4);
+  PetscAssertPointer(help, 5);
   nname[0] = '-';
   nname[1] = 0;
   PetscCall(PetscStrlcat(nname, name, PETSC_BAG_NAME_LENGTH));
@@ -319,25 +320,26 @@ PetscErrorCode PetscBagRegisterBoolArray(PetscBag bag, void *addr, PetscInt msiz
   item->next  = NULL;
   item->msize = msize;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterString - add a string value to a `PetscBag`
+  PetscBagRegisterString - add a string value to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of start of string in struct, for example `&params->mystring`
-.  msize - length of the string space in the struct
-.  mdefault - the initial value
-.  name - name of the string
--  help - longer string with more information about the value
+  Input Parameters:
++ bag      - the bag of values
+. addr     - location of start of string in struct, for example `&params->mystring`
+. msize    - length of the string space in the struct
+. mdefault - the initial value
+. name     - name of the string
+- help     - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
-   Note: The struct should have the field char mystring[msize]; not char *mystring
+  Note:
+  The struct must have the field char mystring[`msize`]; not char *mystring
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -350,11 +352,11 @@ PetscErrorCode PetscBagRegisterString(PetscBag bag, void *addr, PetscInt msize,
   PetscBool    printhelp;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidCharPointer(mdefault, 4);
-  PetscValidCharPointer(name, 5);
-  PetscValidCharPointer(help, 6);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(mdefault, 4);
+  PetscAssertPointer(name, 5);
+  PetscAssertPointer(help, 6);
   nname[0] = '-';
   nname[1] = 0;
   PetscCall(PetscStrlcat(nname, name, PETSC_BAG_NAME_LENGTH));
@@ -370,22 +372,22 @@ PetscErrorCode PetscBagRegisterString(PetscBag bag, void *addr, PetscInt msize,
   if (mdefault != (char *)addr) PetscCall(PetscStrncpy((char *)addr, mdefault, msize - 1));
   PetscCall(PetscOptionsGetString(NULL, bag->bagprefix, nname, (char *)addr, msize, NULL));
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterReal - add a `PetscReal` value to a `PetscBag`
+  PetscBagRegisterReal - add a `PetscReal` value to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of double in struct, for example `&params->r`
-.  mdefault - the initial value
-.  name - name of the variable
--  help - longer string with more information about the value
+  Input Parameters:
++ bag      - the bag of values
+. addr     - location of `PetscReal` in struct, for example `&params->r`
+. mdefault - the initial value
+. name     - name of the variable
+- help     - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -398,10 +400,10 @@ PetscErrorCode PetscBagRegisterReal(PetscBag bag, void *addr, PetscReal mdefault
   PetscBool    printhelp;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidCharPointer(name, 4);
-  PetscValidCharPointer(help, 5);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(name, 4);
+  PetscAssertPointer(help, 5);
   nname[0] = '-';
   nname[1] = 0;
   PetscCall(PetscStrlcat(nname, name, PETSC_BAG_NAME_LENGTH));
@@ -417,26 +419,26 @@ PetscErrorCode PetscBagRegisterReal(PetscBag bag, void *addr, PetscReal mdefault
   item->msize        = 1;
   *(PetscReal *)addr = mdefault;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterScalar - add a `PetscScalar` value to a `PetscBag`
+  PetscBagRegisterScalar - add a `PetscScalar` value to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of scalar in struct, for example `&params->c`
-.  mdefault - the initial value
-.  name - name of the variable
--  help - longer string with more information about the value
+  Input Parameters:
++ bag      - the bag of values
+. addr     - location of `PetscScalar` in struct, for example `&params->c`
+. mdefault - the initial value
+. name     - name of the variable
+- help     - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
-          `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
-          `PetscBagSetFromOptions()`, `PetscBagCreate()`, `PetscBagGetName()`, `PetscBagRegisterEnum()`
+          `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagSetFromOptions()`,
+          `PetscBagCreate()`, `PetscBagGetName()`, `PetscBagRegisterEnum()`
 @*/
 PetscErrorCode PetscBagRegisterScalar(PetscBag bag, void *addr, PetscScalar mdefault, const char *name, const char *help)
 {
@@ -445,10 +447,10 @@ PetscErrorCode PetscBagRegisterScalar(PetscBag bag, void *addr, PetscScalar mdef
   PetscBool    printhelp;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidCharPointer(name, 4);
-  PetscValidCharPointer(help, 5);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(name, 4);
+  PetscAssertPointer(help, 5);
   nname[0] = '-';
   nname[1] = 0;
   PetscCall(PetscStrlcat(nname, name, PETSC_BAG_NAME_LENGTH));
@@ -464,25 +466,25 @@ PetscErrorCode PetscBagRegisterScalar(PetscBag bag, void *addr, PetscScalar mdef
   item->msize          = 1;
   *(PetscScalar *)addr = mdefault;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagRegisterBool - add a `PetscBool` to a `PetscBag`
+  PetscBagRegisterBool - add a `PetscBool` to a `PetscBag`
 
-   Logically Collective on bag
+  Logically Collective
 
-   Input Parameters:
-+  bag - the bag of values
-.  addr - location of logical in struct, for example `&params->b`
-.  mdefault - the initial value, either `PETSC_FALSE` or `PETSC_TRUE`
-.  name - name of the variable
--  help - longer string with more information about the value
+  Input Parameters:
++ bag      - the bag of values
+. addr     - location of `PetscBool` in struct, for example `&params->b`
+. mdefault - the initial value, either `PETSC_FALSE` or `PETSC_TRUE`
+. name     - name of the variable
+- help     - longer string with more information about the value
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
-          `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
+          `PetscBagRegisterInt()`, `PetscBagRegisterScalar()`
           `PetscBagSetFromOptions()`, `PetscBagCreate()`, `PetscBagGetName()`, `PetscBagRegisterEnum()`
 @*/
 PetscErrorCode PetscBagRegisterBool(PetscBag bag, void *addr, PetscBool mdefault, const char *name, const char *help)
@@ -492,10 +494,10 @@ PetscErrorCode PetscBagRegisterBool(PetscBag bag, void *addr, PetscBool mdefault
   PetscBool    printhelp;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(addr, 2);
-  PetscValidCharPointer(name, 4);
-  PetscValidCharPointer(help, 5);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(addr, 2);
+  PetscAssertPointer(name, 4);
+  PetscAssertPointer(help, 5);
   /* the checks here with != PETSC_FALSE and PETSC_TRUE is a special case; here we truly demand that the value be 0 or 1 */
   PetscCheck(mdefault == PETSC_FALSE || mdefault == PETSC_TRUE, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Boolean %s %s must be boolean; integer value %d", name, help, (int)mdefault);
   nname[0] = '-';
@@ -513,18 +515,18 @@ PetscErrorCode PetscBagRegisterBool(PetscBag bag, void *addr, PetscBool mdefault
   item->msize        = 1;
   *(PetscBool *)addr = mdefault;
   PetscCall(PetscBagRegister_Private(bag, item, name, help));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagDestroy - Destroys a `PetscBag`
+  PetscBagDestroy - Destroys a `PetscBag`
 
-   Collective on bag
+  Collective
 
-   Input Parameter:
-.  bag - the bag of values
+  Input Parameter:
+. bag - the bag of values
 
-   Level: beginner
+  Level: beginner
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -535,8 +537,8 @@ PetscErrorCode PetscBagDestroy(PetscBag *bag)
   PetscBagItem nitem;
 
   PetscFunctionBegin;
-  if (!*bag) PetscFunctionReturn(0);
-  PetscValidPointer(*bag, 1);
+  if (!*bag) PetscFunctionReturn(PETSC_SUCCESS);
+  PetscAssertPointer(*bag, 1);
   nitem = (*bag)->bagitems;
   while (nitem) {
     PetscBagItem item = nitem->next;
@@ -547,25 +549,25 @@ PetscErrorCode PetscBagDestroy(PetscBag *bag)
   }
   if ((*bag)->bagprefix) PetscCall(PetscFree((*bag)->bagprefix));
   PetscCall(PetscFree(*bag));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   PetscBagSetFromOptions - Allows setting entries to a `PetscBag` using the options database
+  PetscBagSetFromOptions - Allows setting entries to a `PetscBag` using the options database
 
-   Collective on bag
+  Collective
 
-   Input Parameter:
-.  bag - the bag of values
+  Input Parameter:
+. bag - the bag of values
 
-   Level: beginner
+  Level: beginner
 
-   Note:
-   The options database keys for the entries are of the form `-[bagprefix]_name value`
+  Note:
+  The options database keys for the entries are of the form `-[bagprefix]_name value`
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagDestroy()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
-          `PetscBagSetFromOptions()`, `PetscBagCreate()`, `PetscBagGetName()`, `PetscBagView()`, `PetscBagRegisterEnum()`
+          `PetscBagCreate()`, `PetscBagGetName()`, `PetscBagView()`, `PetscBagRegisterEnum()`
 @*/
 PetscErrorCode PetscBagSetFromOptions(PetscBag bag)
 {
@@ -574,7 +576,7 @@ PetscErrorCode PetscBagSetFromOptions(PetscBag bag)
   PetscInt     n;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
+  PetscAssertPointer(bag, 1);
   PetscCall(PetscStrncpy(helpname, bag->bagname, sizeof(helpname)));
   PetscCall(PetscStrlcat(helpname, " ", sizeof(helpname)));
   PetscCall(PetscStrlcat(helpname, bag->baghelp, sizeof(helpname)));
@@ -623,23 +625,23 @@ PetscErrorCode PetscBagSetFromOptions(PetscBag bag)
     nitem = nitem->next;
   }
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagView - Views a bag of values as either ASCII text or a binary file
+  PetscBagView - Views a bag of values as either ASCII text or a binary file
 
-   Collective on bag
+  Collective
 
-   Input Parameters:
-+  bag - the bag of values
--  viewer - location to view the values
+  Input Parameters:
++ bag  - the bag of values
+- view - location to view the values
 
-   Level: beginner
+  Level: beginner
 
-   Note:
-   Currently PETSc bags saved in a binary file can only be read back
-   in on a machine of the same architecture.
+  Note:
+  Currently PETSc bags saved in a binary file can only be read back
+  in on a machine with the same binary format.
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagDestroy()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`, `PetscBagRegisterEnum()`
@@ -651,7 +653,7 @@ PetscErrorCode PetscBagView(PetscBag bag, PetscViewer view)
   PetscBagItem nitem = bag->bagitems;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
+  PetscAssertPointer(bag, 1);
   PetscValidHeaderSpecific(view, PETSC_VIEWER_CLASSID, 2);
   PetscCall(PetscObjectTypeCompare((PetscObject)view, PETSCVIEWERASCII, &isascii));
   PetscCall(PetscObjectTypeCompare((PetscObject)view, PETSCVIEWERBINARY, &isbinary));
@@ -664,7 +666,7 @@ PetscErrorCode PetscBagView(PetscBag bag, PetscViewer view)
     while (nitem) {
       if (nitem->dtype == PETSC_CHAR) {
         char *value             = (char *)(((char *)bag) + nitem->offset);
-        char  tmp               = value[nitem->msize - 1]; /* special handling for fortran chars wihout null terminator */
+        char  tmp               = value[nitem->msize - 1]; /* special handling for fortran chars without null terminator */
         value[nitem->msize - 1] = 0;
         PetscCall(PetscViewerASCIIPrintf(view, "  %s = %s; %s\n", nitem->name, value, nitem->help));
         value[nitem->msize - 1] = tmp;
@@ -745,17 +747,17 @@ PetscErrorCode PetscBagView(PetscBag bag, PetscViewer view)
       PetscCall(PetscFPrintf(comm, info, "#--- end code written by PetscViewerBinary for MATLAB format ---#\n\n"));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  PetscBagViewFromOptions - Processes command line options to determine if/how a PetscBag is to be viewed.
+  PetscBagViewFromOptions - Processes command line options to determine if/how a `PetscBag` is to be viewed.
 
-  Collective on bag
+  Collective
 
   Input Parameters:
-+ obj   - the object
-. bobj  - optional other object that provides prefix (if NULL then the prefix in obj is used)
++ bag        - the object
+. bobj       - optional other object that provides prefix (if `NULL` then the prefix in obj is used)
 - optionname - option to activate viewing
 
   Level: intermediate
@@ -771,9 +773,9 @@ PetscErrorCode PetscBagViewFromOptions(PetscBag bag, PetscObject bobj, const cha
   PetscBool         flg;
 
   PetscFunctionBegin;
-  if (incall) PetscFunctionReturn(0);
+  if (incall) PetscFunctionReturn(PETSC_SUCCESS);
   incall = PETSC_TRUE;
-  PetscValidPointer(bag, 1);
+  PetscAssertPointer(bag, 1);
   if (bobj) PetscCall(PetscObjectGetOptionsPrefix(bobj, &bprefix));
   prefix = bobj ? bprefix : bag->bagprefix;
   PetscCall(PetscOptionsGetViewer(bag->bagcomm, NULL, prefix, optionname, &viewer, &format, &flg));
@@ -785,22 +787,22 @@ PetscErrorCode PetscBagViewFromOptions(PetscBag bag, PetscObject bobj, const cha
     PetscCall(PetscViewerDestroy(&viewer));
   }
   incall = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscBagLoad - Loads a bag of values from a binary file
+  PetscBagLoad - Loads a bag of values from a binary file
 
-   Collective on view
+  Collective
 
-   Input Parameters:
-+  viewer - file to load values from
--  bag - the bag of values
+  Input Parameters:
++ view - file to load values from
+- bag  - the bag of values
 
-   Note:
-    You must have created and registered all the fields in the bag before loading into it.
+  Level: beginner
 
-   Level: beginner
+  Note:
+  You must have created and registered all the fields in the bag before loading into it. This only loads values.
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagDestroy()`, `PetscBagView()`, `PetscBagGetData()`
           `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -817,7 +819,7 @@ PetscErrorCode PetscBagLoad(PetscViewer view, PetscBag bag)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(view, PETSC_VIEWER_CLASSID, 1);
-  PetscValidPointer(bag, 2);
+  PetscAssertPointer(bag, 2);
   PetscCall(PetscObjectGetComm((PetscObject)view, &comm));
   PetscCallMPI(MPI_Comm_compare(comm, bag->bagcomm, &flag));
   PetscCheck(flag == MPI_CONGRUENT || flag == MPI_IDENT, PETSC_COMM_SELF, PETSC_ERR_ARG_NOTSAMECOMM, "Different communicators in the viewer and bag");
@@ -859,41 +861,41 @@ PetscErrorCode PetscBagLoad(PetscViewer view, PetscBag bag)
     }
     nitem = nitem->next;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscBagCreate - Create a bag of values. A `PetscBag` is a representation of a C struct that can be saved to and read from files, can have values set from the
-    options database
+  PetscBagCreate - Create a bag of values. A `PetscBag` is a representation of a C struct that can be saved to and read from files,
+  can have values set from the options database
 
   Collective
 
-  Level: Intermediate
-
   Input Parameters:
-+  comm - communicator to share bag
--  bagsize - size of the C structure holding the values, for example sizeof(mystruct)
++ comm    - communicator to share bag
+- bagsize - size of the C structure holding the values, for example sizeof(mystruct)
 
   Output Parameter:
-.   bag - the bag of values
+. bag - the bag of values
 
-   Notes:
-   After creating the bag, for each entry in the C struct call the appropriate `PetscBagRegisterInt()` etc to define the C structs layout
+  Level: intermediate
 
-   The size of the A struct must be small enough to fit in a `PetscInt`; by default
-   `PetscInt` is 4 bytes; this means a bag cannot be larger than 2 gigabytes in length.
-   The warning about casting to a shorter length can be ignored below unless your A struct is too large
+  Notes:
+  After creating the bag, for each entry in the C struct call the appropriate `PetscBagRegisterInt()` etc to define the C structs layout
+
+  The size of the A struct must be small enough to fit in a `PetscInt`; by default
+  `PetscInt` is 4 bytes; this means a bag cannot be larger than 2 gigabytes in length.
+  The warning about casting to a shorter length can be ignored below unless your A struct is too large
 
 .seealso: `PetscBag`, `PetscBagGetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
-          `PetscBagSetFromOptions()`, `PetscBagCreate()`, `PetscBagDestroy()`, `PetscBagRegisterEnum()`
+          `PetscBagSetFromOptions()`, `PetscBagDestroy()`, `PetscBagRegisterEnum()`
 @*/
 PetscErrorCode PetscBagCreate(MPI_Comm comm, size_t bagsize, PetscBag *bag)
 {
   const size_t totalsize = bagsize + sizeof(struct _n_PetscBag) + sizeof(PetscScalar);
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 3);
+  PetscAssertPointer(bag, 3);
   PetscCall(PetscInfo(NULL, "Creating Bag with total size %d\n", (int)totalsize));
   PetscCall(PetscCalloc(totalsize, bag));
 
@@ -901,20 +903,20 @@ PetscErrorCode PetscBagCreate(MPI_Comm comm, size_t bagsize, PetscBag *bag)
   (*bag)->bagcomm        = comm;
   (*bag)->bagprefix      = NULL;
   (*bag)->structlocation = (void *)(((char *)(*bag)) + sizeof(PetscScalar) * (sizeof(struct _n_PetscBag) / sizeof(PetscScalar)) + sizeof(PetscScalar));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscBagSetName - Sets the name of a bag of values
+  PetscBagSetName - Sets the name of a bag of values
 
   Not Collective
 
-  Level: Intermediate
+  Level: intermediate
 
   Input Parameters:
-+   bag - the bag of values
-.   name - the name assigned to the bag
--   help - help message for bag
++ bag  - the bag of values
+. name - the name assigned to the bag
+- help - help message for bag
 
 .seealso: `PetscBag`, `PetscBagGetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -923,26 +925,26 @@ PetscErrorCode PetscBagCreate(MPI_Comm comm, size_t bagsize, PetscBag *bag)
 PetscErrorCode PetscBagSetName(PetscBag bag, const char *name, const char *help)
 {
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidCharPointer(name, 2);
-  PetscValidCharPointer(help, 3);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(name, 2);
+  PetscAssertPointer(help, 3);
   PetscCall(PetscStrncpy(bag->bagname, name, PETSC_BAG_NAME_LENGTH - 1));
   PetscCall(PetscStrncpy(bag->baghelp, help, PETSC_BAG_HELP_LENGTH - 1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscBagGetName - Gets the name of a bag of values
+  PetscBagGetName - Gets the name of a bag of values
 
   Not Collective
 
-  Level: Intermediate
+  Level: intermediate
 
   Input Parameter:
-.   bag - the bag of values
+. bag - the bag of values
 
   Output Parameter:
-.   name - the name assigned to the bag
+. name - the name assigned to the bag
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`, `PetscBagGetData()`
           `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -951,25 +953,26 @@ PetscErrorCode PetscBagSetName(PetscBag bag, const char *name, const char *help)
 PetscErrorCode PetscBagGetName(PetscBag bag, char **name)
 {
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(name, 2);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(name, 2);
   *name = bag->bagname;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscBagGetData - Gives back the user - access to memory that
-    can be used for storing user-data-structure
+  PetscBagGetData - Gives back the user - access to memory that
+  can be used for storing user-data-structure
 
   Not Collective
 
-  Level: Intermediate
-
   Input Parameter:
-.   bag - the bag of values
+. bag - the bag of values
 
   Output Parameter:
-.   data - pointer to memory that will have user-data-structure, this can be cast to a pointer of the type the C struct used in defining the bag
+. data - pointer to memory that will have user-data-structure, this can be cast to a pointer of the type the C struct used in
+    defining the bag
+
+  Level: intermediate
 
 .seealso: `PetscBag`, `PetscBagSetName()`, `PetscBagView()`, `PetscBagLoad()`
           `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
@@ -978,51 +981,50 @@ PetscErrorCode PetscBagGetName(PetscBag bag, char **name)
 PetscErrorCode PetscBagGetData(PetscBag bag, void **data)
 {
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(data, 2);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(data, 2);
   *data = bag->structlocation;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   PetscBagSetOptionsPrefix - Sets the prefix used for searching for all
   `PetscBag` items in the options database.
 
-  Logically collective on bag
+  Logically Collective
 
-  Level: Intermediate
+  Level: intermediate
 
   Input Parameters:
-+   bag - the bag of values
--   prefix - the prefix to prepend all Bag item names with.
++ bag - the bag of values
+- pre - the prefix to prepend all Bag item names with.
 
-  NOTES: Must be called prior to registering any of the bag items.
+  Note:
+  Must be called prior to registering any of the bag items.
 
 .seealso: `PetscBag`, `PetscBagRegisterReal()`, `PetscBagRegisterInt()`, `PetscBagRegisterBool()`, `PetscBagRegisterScalar()`
           `PetscBagSetFromOptions()`, `PetscBagCreate()`, `PetscBagDestroy()`, `PetscBagRegisterEnum()`
 @*/
-
 PetscErrorCode PetscBagSetOptionsPrefix(PetscBag bag, const char pre[])
 {
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
+  PetscAssertPointer(bag, 1);
   if (pre) {
-    PetscValidCharPointer(pre, 2);
+    PetscAssertPointer(pre, 2);
     PetscCheck(pre[0] != '-', PETSC_COMM_SELF, PETSC_ERR_ARG_WRONG, "Options prefix should not begin with a hyphen");
     PetscCall(PetscFree(bag->bagprefix));
     PetscCall(PetscStrallocpy(pre, &(bag->bagprefix)));
   } else PetscCall(PetscFree(bag->bagprefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   PetscBagGetNames - Get the names of all entries in the bag
 
-  Not collective
+  Not Collective
 
-  Input Parameters:
-+ bag   - the bag of values
-- names - array of the correct size to hold names, must be long enough to hold all the names
+  Input Parameter:
+. bag - the bag of values
 
   Output Parameter:
 . names - array of char pointers for names
@@ -1037,8 +1039,8 @@ PetscErrorCode PetscBagGetNames(PetscBag bag, const char *names[])
   PetscBagItem nitem = bag->bagitems;
 
   PetscFunctionBegin;
-  PetscValidPointer(bag, 1);
-  PetscValidPointer(names, 2);
+  PetscAssertPointer(bag, 1);
+  PetscAssertPointer(names, 2);
   for (PetscInt n = 0; nitem; ++n, nitem = nitem->next) names[n] = nitem->name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
