@@ -30,44 +30,44 @@ PetscBool                PetscLogPrintInfo
 FILE                    *PetscInfoFile                                             = NULL;
 
 /*@
-    PetscInfoEnabled - Checks whether a given OBJECT_CLASSID is allowed to print using `PetscInfo()`
+  PetscInfoEnabled - Checks whether a given `PetscClassid` is allowed to print using `PetscInfo()`
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   classid - `PetscClassid` retrieved from a `PetscObject` e.g. `VEC_CLASSID`
+  Input Parameter:
+. classid - `PetscClassid` retrieved from a `PetscObject` e.g. `VEC_CLASSID`
 
-    Output Parameter:
-.   enabled - `PetscBool` indicating whether this classid is allowed to print
+  Output Parameter:
+. enabled - `PetscBool` indicating whether this classid is allowed to print
 
-    Level: advanced
+  Level: advanced
 
-    Note:
-    Use `PETSC_SMALLEST_CLASSID` to check if "sys" `PetscInfo()` calls are enabled. When PETSc is configured with debugging
-    support this function checks if classid >= `PETSC_SMALLEST_CLASSID`, otherwise it assumes valid classid.
+  Note:
+  Use `PETSC_SMALLEST_CLASSID` to check if "sys" `PetscInfo()` calls are enabled. When PETSc is configured with debugging
+  support this function checks if classid >= `PETSC_SMALLEST_CLASSID`, otherwise it assumes valid classid.
 
-.seealso: `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoGetInfo()`, `PetscObjectGetClassid()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoGetInfo()`, `PetscObjectGetClassid()`
 @*/
 PetscErrorCode PetscInfoEnabled(PetscClassId classid, PetscBool *enabled)
 {
   PetscFunctionBegin;
-  PetscValidBoolPointer(enabled, 2);
+  PetscAssertPointer(enabled, 2);
   PetscCheck(classid >= PETSC_SMALLEST_CLASSID, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Classid (current: %d) must be equal to or greater than PETSC_SMALLEST_CLASSID", classid);
   *enabled = (PetscBool)(PetscLogPrintInfo && PetscInfoFlags[classid - PETSC_SMALLEST_CLASSID]);
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    PetscInfoAllow - Enables/disables `PetscInfo()` messages
+  PetscInfoAllow - Enables/disables `PetscInfo()` messages
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   flag - `PETSC_TRUE` or `PETSC_FALSE`
+  Input Parameter:
+. flag - `PETSC_TRUE` or `PETSC_FALSE`
 
-    Level: advanced
+  Level: advanced
 
-.seealso: `PetscInfo()`, `PetscInfoEnabled()`, `PetscInfoGetInfo()`, `PetscInfoSetFromOptions()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoEnabled()`, `PetscInfoGetInfo()`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoAllow(PetscBool flag)
 {
@@ -77,20 +77,20 @@ PetscErrorCode PetscInfoAllow(PetscBool flag)
 }
 
 /*@C
-    PetscInfoSetFile - Sets the printing destination for all `PetscInfo()` calls
+  PetscInfoSetFile - Sets the printing destination for all `PetscInfo()` calls
 
-    Not Collective
+  Not Collective
 
-    Input Parameters:
-+   filename - Name of the file where `PetscInfo()` will print to
--   mode - Write mode passed to `PetscFOpen()`
+  Input Parameters:
++ filename - Name of the file where `PetscInfo()` will print to
+- mode     - Write mode passed to `PetscFOpen()`
 
-    Level: advanced
+  Level: advanced
 
-    Note:
-    Use `filename = NULL` to set `PetscInfo()` to write to `PETSC_STDOUT`.
+  Note:
+  Use `filename = NULL` to set `PetscInfo()` to write to `PETSC_STDOUT`.
 
-.seealso: `PetscInfo()`, `PetscInfoSetFile()`, `PetscInfoSetFromOptions()`, `PetscFOpen()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoGetFile()`, `PetscInfoSetFromOptions()`, `PetscFOpen()`
 @*/
 PetscErrorCode PetscInfoSetFile(const char filename[], const char mode[])
 {
@@ -101,8 +101,8 @@ PetscErrorCode PetscInfoSetFile(const char filename[], const char mode[])
     PetscMPIInt rank;
     char        fname[PETSC_MAX_PATH_LEN], tname[11];
 
-    PetscValidCharPointer(filename, 1);
-    PetscValidCharPointer(mode, 2);
+    PetscAssertPointer(filename, 1);
+    PetscAssertPointer(mode, 2);
     PetscCall(PetscFixFilename(filename, fname));
     PetscCall(PetscStrallocpy(fname, &PetscInfoFilename));
     PetscCallMPI(MPI_Comm_rank(PETSC_COMM_WORLD, &rank));
@@ -125,61 +125,61 @@ PetscErrorCode PetscInfoSetFile(const char filename[], const char mode[])
 }
 
 /*@C
-    PetscInfoGetFile - Gets the `filename` and `FILE` pointer of the file where `PetscInfo()` prints to
+  PetscInfoGetFile - Gets the `filename` and `FILE` pointer of the file where `PetscInfo()` prints to
 
-    Not Collective; No Fortran Support
+  Not Collective; No Fortran Support
 
-    Output Parameters:
-+   filename - The name of the output file
--   InfoFile - The `FILE` pointer for the output file
+  Output Parameters:
++ filename - The name of the output file
+- InfoFile - The `FILE` pointer for the output file
 
-    Level: advanced
+  Level: advanced
 
-    Note:
-    This routine allocates and copies the `filename` so that the `filename` survives `PetscInfoDestroy()`. The user is
-    therefore responsible for freeing the allocated `filename` pointer afterwards.
+  Note:
+  This routine allocates and copies the `filename` so that the `filename` survives `PetscInfoDestroy()`. The user is
+  therefore responsible for freeing the allocated `filename` pointer afterwards.
 
-.seealso: `PetscInfo()`, `PetscInfoSetFile()`, `PetscInfoSetFromOptions()`, `PetscInfoDestroy()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoSetFile()`, `PetscInfoSetFromOptions()`, `PetscInfoDestroy()`
 @*/
 PetscErrorCode PetscInfoGetFile(char **filename, FILE **InfoFile)
 {
   PetscFunctionBegin;
-  PetscValidPointer(filename, 1);
-  PetscValidPointer(InfoFile, 2);
+  PetscAssertPointer(filename, 1);
+  PetscAssertPointer(InfoFile, 2);
   PetscCall(PetscStrallocpy(PetscInfoFilename, filename));
   *InfoFile = PetscInfoFile;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscInfoSetClasses - Sets the classes which `PetscInfo()` is filtered for/against
+  PetscInfoSetClasses - Sets the classes which `PetscInfo()` is filtered for/against
 
-    Not Collective; No Fortran Support
+  Not Collective; No Fortran Support
 
-    Input Parameters:
-+   exclude - Whether or not to invert the filter, i.e. if exclude is true, `PetscInfo()` will print from every class that
+  Input Parameters:
++ exclude    - Whether or not to invert the filter, i.e. if exclude is true, `PetscInfo()` will print from every class that
     is NOT one of the classes specified
-.   n - Number of classes to filter for (size of `classnames`)
--   classnames - String array containing the names of classes to filter for, e.g. "vec"
+. n          - Number of classes to filter for (size of `classnames`)
+- classnames - String array containing the names of classes to filter for, e.g. "vec"
 
-    Level: developer
+  Level: developer
 
-    Notes:
-    This function CANNOT be called after `PetscInfoGetClass()` or `PetscInfoProcessClass()` has been called.
+  Notes:
+  This function CANNOT be called after `PetscInfoGetClass()` or `PetscInfoProcessClass()` has been called, unless the user calls `PetscInfoDestroy()` first.
 
-    Names in the `classnames` list should correspond to the names returned by `PetscObjectGetClassName()`.
+  Names in the `classnames` list should correspond to the names returned by `PetscObjectGetClassName()`.
 
-    This function only sets the list of class names.
-    The actual filtering is deferred to `PetscInfoProcessClass()`, except of sys which is processed right away.
-    The reason for this is that we need to set the list of included/excluded classes before their classids are known.
-    Typically the classid is assigned and `PetscInfoProcessClass()` called in <Class>InitializePackage() (e.g. `VecInitializePackage()`).
+  This function only sets the list of class names.
+  The actual filtering is deferred to `PetscInfoProcessClass()`, except of sys which is processed right away.
+  The reason for this is that we need to set the list of included/excluded classes before their classids are known.
+  Typically the classid is assigned and `PetscInfoProcessClass()` called in <Class>InitializePackage() (e.g. `VecInitializePackage()`).
 
-.seealso: `PetscInfo()`, `PetscInfoGetClass()`, `PetscInfoProcessClass()`, `PetscInfoSetFromOptions()`, `PetscStrToArray()`, `PetscObjectGetName()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoGetClass()`, `PetscInfoProcessClass()`, `PetscInfoSetFromOptions()`, `PetscStrToArray()`, `PetscObjectGetName()`
 @*/
 PetscErrorCode PetscInfoSetClasses(PetscBool exclude, PetscInt n, const char *const *classnames)
 {
   PetscFunctionBegin;
-  PetscCheck(!PetscInfoClassesLocked, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "PetscInfoSetClasses() cannot be called after PetscInfoGetClass() or PetscInfoProcessClass()");
+  PetscCheck(!PetscInfoClassesLocked, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "Trying to modify PetscInfo() configuration after it has been locked to a read-only state. Usually, this is an *error*! To re-enable modification, you must reset PetscInfo() by calling PetscInfoDestroy() first");
   PetscCall(PetscStrNArrayDestroy(PetscInfoNumClasses, &PetscInfoClassnames));
   PetscCall(PetscStrNArrayallocpy(n, classnames, &PetscInfoClassnames));
   PetscInfoNumClasses    = n;
@@ -195,63 +195,63 @@ PetscErrorCode PetscInfoSetClasses(PetscBool exclude, PetscInt n, const char *co
 }
 
 /*@C
-    PetscInfoGetClass - Indicates whether the provided `classname` is marked as a filter in `PetscInfo()` as set by `PetscInfoSetClasses()`
+  PetscInfoGetClass - Indicates whether the provided `classname` is marked as a filter in `PetscInfo()` as set by `PetscInfoSetClasses()`
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   classname - Name of the class to search for
+  Input Parameter:
+. classname - Name of the class to search for
 
-    Output Parameter:
-.   found - `PetscBool` indicating whether the classname was found
+  Output Parameter:
+. found - `PetscBool` indicating whether the classname was found
 
-    Level: developer
+  Level: developer
 
-    Note:
-    Use `PetscObjectGetName()` to retrieve an appropriate classname
+  Note:
+  Use `PetscObjectGetName()` to retrieve an appropriate classname
 
-.seealso: `PetscInfo()`, `PetscInfoSetClasses()`, `PetscInfoSetFromOptions()`, `PetscObjectGetName()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoSetClasses()`, `PetscInfoSetFromOptions()`, `PetscObjectGetName()`
 @*/
 PetscErrorCode PetscInfoGetClass(const char *classname, PetscBool *found)
 {
   PetscInt unused;
 
   PetscFunctionBegin;
-  PetscValidCharPointer(classname, 1);
-  PetscValidBoolPointer(found, 2);
+  PetscAssertPointer(classname, 1);
+  PetscAssertPointer(found, 2);
   PetscCall(PetscEListFind(PetscInfoNumClasses, (const char *const *)PetscInfoClassnames, classname ? classname : "sys", &unused, found));
   PetscInfoClassesLocked = PETSC_TRUE;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    PetscInfoGetInfo - Returns the current state of several important flags for `PetscInfo()`
+  PetscInfoGetInfo - Returns the current state of several flags for `PetscInfo()`
 
-    Not Collective
+  Not Collective
 
-    Output Parameters:
-+   infoEnabled - `PETSC_TRUE` if `PetscInfoAllow`(`PETSC_TRUE`) has been called
-.   classesSet - `PETSC_TRUE` if the list of classes to filter for has been set
-.   exclude - `PETSC_TRUE` if the class filtering for `PetscInfo()` is inverted
-.   locked - `PETSC_TRUE` if the list of classes to filter for has been locked
--   commSelfFlag - Enum indicating whether `PetscInfo()` will print for communicators of size 1, any size != 1, or all
+  Output Parameters:
++ infoEnabled  - `PETSC_TRUE` if `PetscInfoAllow`(`PETSC_TRUE`) has been called
+. classesSet   - `PETSC_TRUE` if the list of classes to filter for has been set
+. exclude      - `PETSC_TRUE` if the class filtering for `PetscInfo()` is inverted
+. locked       - `PETSC_TRUE` if the list of classes to filter for has been locked
+- commSelfFlag - Enum indicating whether `PetscInfo()` will print for communicators of size 1, any size != 1, or all
     communicators
 
-    Level: developer
+  Level: developer
 
-    Note:
-    Initially commSelfFlag = `PETSC_INFO_COMM_ALL`
+  Note:
+  Initially commSelfFlag = `PETSC_INFO_COMM_ALL`
 
-.seealso: `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFilterCommSelf`, `PetscInfoSetFromOptions()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFilterCommSelf`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoGetInfo(PetscBool *infoEnabled, PetscBool *classesSet, PetscBool *exclude, PetscBool *locked, PetscInfoCommFlag *commSelfFlag)
 {
   PetscFunctionBegin;
-  if (infoEnabled) PetscValidBoolPointer(infoEnabled, 1);
-  if (classesSet) PetscValidBoolPointer(classesSet, 2);
-  if (exclude) PetscValidBoolPointer(exclude, 3);
-  if (locked) PetscValidBoolPointer(locked, 4);
-  if (commSelfFlag) PetscValidPointer(commSelfFlag, 5);
+  if (infoEnabled) PetscAssertPointer(infoEnabled, 1);
+  if (classesSet) PetscAssertPointer(classesSet, 2);
+  if (exclude) PetscAssertPointer(exclude, 3);
+  if (locked) PetscAssertPointer(locked, 4);
+  if (commSelfFlag) PetscAssertPointer(commSelfFlag, 5);
   if (infoEnabled) *infoEnabled = PetscLogPrintInfo;
   if (classesSet) *classesSet = PetscInfoClassesSet;
   if (exclude) *exclude = PetscInfoInvertClasses;
@@ -261,21 +261,21 @@ PetscErrorCode PetscInfoGetInfo(PetscBool *infoEnabled, PetscBool *classesSet, P
 }
 
 /*@C
-    PetscInfoProcessClass - Activates or deactivates a class based on the filtering status of `PetscInfo()`
+  PetscInfoProcessClass - Activates or deactivates a class based on the filtering status of `PetscInfo()`
 
-    Not Collective
+  Not Collective
 
-    Input Parameters:
-+   classname - Name of the class to activate/deactivate `PetscInfo()` for
-.   numClassID - Number of entries in `classIDs`
--   classIDs - Array containing all of the `PetscClassId`s associated with `classname`
+  Input Parameters:
++ classname  - Name of the class to activate/deactivate `PetscInfo()` for
+. numClassID - Number of entries in `classIDs`
+- classIDs   - Array containing all of the `PetscClassId`s associated with `classname`
 
-      Options Database Key:
-.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, see `PetscInfo()`.
+  Options Database Key:
+. -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, see `PetscInfo()`.
 
-    Level: developer
+  Level: developer
 
-.seealso: `PetscInfo()`, `PetscInfoActivateClass()`, `PetscInfoDeactivateClass()`, `PetscInfoSetFromOptions()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoActivateClass()`, `PetscInfoDeactivateClass()`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoProcessClass(const char classname[], PetscInt numClassID, const PetscClassId classIDs[])
 {
@@ -283,9 +283,9 @@ PetscErrorCode PetscInfoProcessClass(const char classname[], PetscInt numClassID
   char      logList[256];
 
   PetscFunctionBegin;
-  PetscValidCharPointer(classname, 1);
+  PetscAssertPointer(classname, 1);
   PetscAssert(numClassID > 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Number of classids %" PetscInt_FMT " <= 0", numClassID);
-  if (numClassID) PetscValidPointer(classIDs, 3);
+  if (numClassID) PetscAssertPointer(classIDs, 3);
   PetscCall(PetscInfoGetInfo(&enabled, NULL, &exclude, NULL, NULL));
   PetscCall(PetscOptionsDeprecated_Private(NULL, "-info_exclude", NULL, "3.13", "Use ~ with -info to indicate classes to exclude"));
   PetscCall(PetscOptionsGetString(NULL, NULL, "-info_exclude", logList, sizeof(logList), &opt));
@@ -316,19 +316,19 @@ PetscErrorCode PetscInfoProcessClass(const char classname[], PetscInt numClassID
 }
 
 /*@
-    PetscInfoSetFilterCommSelf - Sets `PetscInfoCommFlag` enum to determine communicator filtering for `PetscInfo()`
+  PetscInfoSetFilterCommSelf - Sets `PetscInfoCommFlag` enum to determine communicator filtering for `PetscInfo()`
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   commSelfFlag - Enum value indicating method with which to filter `PetscInfo()` based on the size of the communicator of the object calling `PetscInfo()`
+  Input Parameter:
+. commSelfFlag - Enum value indicating method with which to filter `PetscInfo()` based on the size of the communicator of the object calling `PetscInfo()`
 
-    Options Database Key:
-.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
+  Options Database Key:
+. -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
 
-    Level: advanced
+  Level: advanced
 
-.seealso: `PetscInfo()`, `PetscInfoGetInfo()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoGetInfo()`
 @*/
 PetscErrorCode PetscInfoSetFilterCommSelf(PetscInfoCommFlag commSelfFlag)
 {
@@ -338,22 +338,22 @@ PetscErrorCode PetscInfoSetFilterCommSelf(PetscInfoCommFlag commSelfFlag)
 }
 
 /*@
-    PetscInfoSetFromOptions - Configure `PetscInfo()` using command line options, enabling or disabling various calls to `PetscInfo()`
+  PetscInfoSetFromOptions - Configure `PetscInfo()` using command line options, enabling or disabling various calls to `PetscInfo()`
 
-    Not Collective
+  Not Collective
 
-    Input Parameter:
-.   options - Options database, use `NULL` for default global database
+  Input Parameter:
+. options - Options database, use `NULL` for default global database
 
-    Options Database Key:
-.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
+  Options Database Key:
+. -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
 
-    Level: advanced
+  Level: advanced
 
-    Note:
-    This function is called automatically during `PetscInitialize()` so users usually do not need to call it themselves.
+  Note:
+  This function is called automatically during `PetscInitialize()` so users usually do not need to call it themselves.
 
-.seealso: `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFile()`, `PetscInfoSetClasses()`, `PetscInfoSetFilterCommSelf()`, `PetscInfoDestroy()`
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFile()`, `PetscInfoSetClasses()`, `PetscInfoSetFilterCommSelf()`, `PetscInfoDestroy()`
 @*/
 PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
 {
@@ -419,26 +419,35 @@ PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
 
   Level: developer
 
-  Note:
+  Notes:
   This is automatically called in `PetscFinalize()`. Useful for changing filters mid-program, or culling subsequent
   `PetscInfo()` calls down the line.
 
-.seealso: `PetscInfo()`, `PetscInfoSetFromOptions()`
+  Users calling this routine midway through a program should note that `PetscInfoDestroy()`
+  constitutes a full reset of `PetscInfo()`. It flushes, then closes, the current info file,
+  re-enables all classes, and resets all internal state. Finally -- and perhaps crucially -- it
+  disables `PetscInfo()` as-if-by `PetscInfoAllow(PETSC_FALSE)`.
+
+.seealso: [](sec_PetscInfo), `PetscInfo()`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoDestroy(void)
 {
   PetscFunctionBegin;
   PetscCall(PetscInfoAllow(PETSC_FALSE));
   PetscCall(PetscStrNArrayDestroy(PetscInfoNumClasses, &PetscInfoClassnames));
-  PetscCall(PetscFFlush(PetscInfoFile));
-  if (PetscInfoFilename) PetscCall(PetscFClose(PETSC_COMM_SELF, PetscInfoFile));
-  PetscCall(PetscFree(PetscInfoFilename));
+  if (PetscInfoFile) PetscCall(PetscFFlush(PetscInfoFile));
+  if (PetscInfoFilename) {
+    PetscAssert(PetscInfoFile, PETSC_COMM_SELF, PETSC_ERR_ARG_NULL, "Have non-null PetscInfo file '%s', but corresponding FILE handle is null!", PetscInfoFilename);
+    PetscCall(PetscFree(PetscInfoFilename));
+    PetscCall(PetscFClose(PETSC_COMM_SELF, PetscInfoFile));
+  }
   PetscAssert(PETSC_STATIC_ARRAY_LENGTH(PetscInfoFlags) == PETSC_STATIC_ARRAY_LENGTH(PetscInfoNames), PETSC_COMM_SELF, PETSC_ERR_PLIB, "PetscInfoFlags and PetscInfoNames must be the same size");
   for (size_t i = 0; i < PETSC_STATIC_ARRAY_LENGTH(PetscInfoFlags); ++i) {
     PetscInfoFlags[i] = 1;
     PetscCall(PetscFree(PetscInfoNames[i]));
   }
 
+  PetscInfoFile          = NULL;
   PetscInfoClassesLocked = PETSC_FALSE;
   PetscInfoInvertClasses = PETSC_FALSE;
   PetscInfoClassesSet    = PETSC_FALSE;
@@ -463,15 +472,15 @@ static PetscErrorCode PetscInfoSetClassActivation_Private(PetscClassId classid,
   Input Parameter:
 . classid - The object class,  e.g., `MAT_CLASSID`, `SNES_CLASSID`, etc.
 
-    Options Database Key:
-.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
+  Options Database Key:
+. -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
 
   Level: developer
 
   Note:
   One can pass 0 to deactivate all messages that are not associated with an object.
 
-.seealso: `PetscInfoActivateClass()`, `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFromOptions()`
+.seealso: [](sec_PetscInfo), `PetscInfoActivateClass()`, `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoDeactivateClass(PetscClassId classid)
 {
@@ -488,15 +497,15 @@ PetscErrorCode PetscInfoDeactivateClass(PetscClassId classid)
   Input Parameter:
 . classid - The object class, e.g., `MAT_CLASSID`, `SNES_CLASSID`, etc.
 
-    Options Database Key:
-.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
+  Options Database Key:
+. -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
 
   Level: developer
 
   Note:
   One can pass 0 to activate all messages that are not associated with an object.
 
-.seealso: `PetscInfoDeactivateClass()`, `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFromOptions()`
+.seealso: [](sec_PetscInfo), `PetscInfoDeactivateClass()`, `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoActivateClass(PetscClassId classid)
 {
@@ -513,43 +522,38 @@ PetscErrorCode PetscInfoActivateClass(PetscClassId classid)
 PETSC_INTERN FILE *petsc_history;
 
 /*MC
-    PetscInfo - Logs informative data
+  PetscInfo - Logs informative data
 
-   Synopsis:
-       #include <petscsys.h>
-       PetscErrorCode PetscInfo(PetscObject obj, const char message[])
-       PetscErrorCode PetscInfo(PetscObject obj, const char formatmessage[],arg1)
-       PetscErrorCode PetscInfo(PetscObject obj, const char formatmessage[],arg1,arg2)
-       ...
+  Synopsis:
+  #include <petsclog.h>
+  PetscErrorCode PetscInfo(PetscObject obj, const char message[], ...)
 
-    Collective
+  Collective
 
-    Input Parameters:
-+   obj - object most closely associated with the logging statement or `NULL`
-.   message - logging message
-.   formatmessage - logging message using standard "printf" format
--   arg1, arg2, ... - arguments of the format
+  Input Parameters:
++ obj     - object most closely associated with the logging statement or `NULL`
+- message - logging message using standard "printf" format
 
-      Options Database Key:
-.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
+  Options Database Key:
+. -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed
 
-    Level: intermediate
+  Level: intermediate
 
-    Notes:
-    `PetscInfo()` prints only from the first processor in the communicator of obj.
-    If obj is NULL, the `PETSC_COMM_SELF` communicator is used, i.e. every rank of `PETSC_COMM_WORLD` prints the message.
+  Notes:
+  `PetscInfo()` prints only from the first processor in the communicator of `obj`.
+  If `obj` is `NULL`, the `PETSC_COMM_SELF` communicator is used, i.e. every rank of `PETSC_COMM_WORLD` prints the message.
 
-    The optional <list,of,classnames> is a comma separated list of enabled classes, e.g. vec,mat,ksp.
-    If this list is not specified, all classes are enabled.
-    Prepending the list with ~ means inverted selection, i.e. all classes except the listed are enabled.
-    A special classname `sys` relates to `PetscInfo()` with obj being `NULL`.
+  The optional <list,of,classnames> is a comma separated list of enabled classes, e.g. `vec,mat,ksp`.
+  If this list is not specified, all classes are enabled.
+  Prepending the list with ~ means inverted selection, i.e. all classes except the listed are enabled.
+  A special classname `sys` relates to `PetscInfo()` with `obj` being `NULL`.
 
-    The optional keyword `self` specifies that `PetscInfo()` is enabled only for a communicator size of 1 (e.g. `PETSC_COMM_SELF`).
-    By contrast, ~self means that `PetscInfo()` is enabled only for communicator size > 1 (e.g. `PETSC_COMM_WORLD`), i.e. those `PetscInfo()` calls which print from every rank of `PETSC_COMM_WORLD` are disabled.
+  The optional keyword `self` specifies that `PetscInfo()` is enabled only for a communicator size of 1 (e.g. `PETSC_COMM_SELF`).
+  By contrast, ~self means that `PetscInfo()` is enabled only for communicator size > 1 (e.g. `PETSC_COMM_WORLD`), i.e. those `PetscInfo()` calls which print from every rank of `PETSC_COMM_WORLD` are disabled.
 
-    All classname/self matching is case insensitive. Filename is case sensitive.
+  All classname/self matching is case insensitive. Filename is case sensitive.
 
-    Example of Usage:
+  Example of Usage:
 .vb
      Mat A;
      PetscInt alpha;
@@ -557,26 +561,29 @@ PETSC_INTERN FILE *petsc_history;
      PetscInfo(A,"Matrix uses parameter alpha=%" PetscInt_FMT "\n",alpha);
 .ve
 
-    Options Examples:
-    Each call of the form
+  Examples using Options:
+  Each call of the form
 .vb
      PetscInfo(obj, msg);
      PetscInfo(obj, msg, arg1);
      PetscInfo(obj, msg, arg1, arg2);
 .ve
-    is evaluated as follows.
+  is evaluated as follows.
 .vb
-    -info or -info :: prints msg to PETSC_STDOUT, for any obj regardless class or communicator
-    -info :mat:self prints msg to PETSC_STDOUT only if class of obj is Mat, and its communicator has size = 1
-    -info myInfoFileName:~vec:~self prints msg to file named myInfoFileName, only if the obj's class is NULL or other than Vec, and obj's communicator has size > 1
-    -info :sys prints to PETSC_STDOUT only if obj is NULL
-    -info :sys:~self deactivates all info messages because sys means obj = NULL which implies PETSC_COMM_SELF but ~self filters out everything on PETSC_COMM_SELF.
+    -info or -info :: prints `msg` to `PETSC_STDOUT`, for any PETSc `obj` regardless class or communicator
+    -info :mat:self prints `msg` to `PETSC_STDOUT` only if class of `obj` is `Mat`, and its communicator has size = 1
+    -info myInfoFileName:~vec:~self prints `msg` to file named `myInfoFileName`, only if the `obj`'s class is `NULL` or other than `Vec`, and `obj`'s communicator has size > 1
+    -info :sys prints to `PETSC_STDOUT` only if `obj` is `NULL`
+    -info :sys:~self deactivates all info messages because `sys` means `obj` = `NULL` which implies `PETSC_COMM_SELF` but `~self` filters out everything on `PETSC_COMM_SELF`.
 .ve
-    Fortran Note:
-    This function does not take the `obj` argument, there is only the `PetscInfo()`
-     version, not `PetscInfo()` etc.
 
-.seealso: `PetscInfoAllow()`, `PetscInfoSetFromOptions()`
+  Fortran Notes:
+  This function does not take the `obj` argument, there is only the `PetscInfo()`
+  version, not `PetscInfo()` etc.
+
+.seealso: [](sec_PetscInfo), `PetscInfoAllow()`, `PetscInfoSetFromOptions()`, `PetscInfoEnabled()`, `PetscInfoSetFile()`, `PetscInfoGetFile()`, `PetscInfoSetClasses()`,
+          `PetscInfoGetClass()`, `PetscInfoGetInfo()`, `PetscInfoProcessClass()`, `PetscInfoSetFilterCommSelf()`, `PetscInfoDestroy()`, `PetscInfoDeactivateClass()`,
+          `PetscInfoActivateClass()`
 M*/
 PetscErrorCode PetscInfo_Private(const char func[], PetscObject obj, const char message[], ...)
 {
@@ -584,16 +591,20 @@ PetscErrorCode PetscInfo_Private(const char func[], PetscObject obj, const char
   PetscBool    enabled = PETSC_FALSE;
   MPI_Comm     comm    = PETSC_COMM_SELF;
   PetscMPIInt  rank;
+  const char  *otype = NULL;
 
   PetscFunctionBegin;
   if (obj) {
     PetscValidHeader(obj, 2);
     classid = obj->classid;
   }
-  PetscValidCharPointer(message, 3);
+  PetscAssertPointer(message, 3);
   PetscCall(PetscInfoEnabled(classid, &enabled));
   if (!enabled) PetscFunctionReturn(PETSC_SUCCESS);
-  if (obj) PetscCall(PetscObjectGetComm(obj, &comm));
+  if (obj) {
+    PetscCall(PetscObjectGetComm(obj, &comm));
+    PetscCall(PetscObjectGetType(obj, &otype));
+  }
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
   /* rank > 0 always jumps out */
   if (rank) PetscFunctionReturn(PETSC_SUCCESS);
@@ -616,7 +627,11 @@ PetscErrorCode PetscInfo_Private(const char func[], PetscObject obj, const char
 
     PetscLogPrintInfo = PETSC_FALSE;
     PetscCallMPI(MPI_Comm_rank(MPI_COMM_WORLD, &urank));
-    PetscCall(PetscSNPrintf(string, PETSC_STATIC_ARRAY_LENGTH(string), "[%d] <%s> %s(): ", urank, PetscInfoNames[classid - PETSC_SMALLEST_CLASSID], func));
+    if (otype) {
+      PetscCall(PetscSNPrintf(string, PETSC_STATIC_ARRAY_LENGTH(string), "[%d] <%s:%s> %s(): ", urank, PetscInfoNames[classid - PETSC_SMALLEST_CLASSID], otype, func));
+    } else {
+      PetscCall(PetscSNPrintf(string, PETSC_STATIC_ARRAY_LENGTH(string), "[%d] <%s> %s(): ", urank, PetscInfoNames[classid - PETSC_SMALLEST_CLASSID], func));
+    }
     PetscCall(PetscStrlen(string, &len));
     va_start(Argp, message);
     PetscCall(PetscVSNPrintf(string + len, 8 * 1024 - len, message, &fullLength, Argp));
