@@ -34,21 +34,21 @@ static PetscErrorCode PetscFortranCallbackFinalize(void)
 }
 
 /*@C
-   PetscFortranCallbackRegister - register a type+subtype callback. This is used by the PETSc Fortran interface to allow the use of user Fortran functions as arguments
-   to PETSc functions that take function pointers
+  PetscFortranCallbackRegister - register a type+subtype callback. This is used by the PETSc Fortran interface to allow the use of user Fortran functions
+  as arguments to PETSc functions that take function pointers
 
-   Not Collective
+  Not Collective
 
-   Input Parameters:
-+  classid - ID of class on which to register callback
--  subtype - subtype string, or NULL for class ids
+  Input Parameters:
++ classid - ID of class on which to register callback
+- subtype - subtype string, or `NULL` for class ids
 
-   Output Parameter:
-.  id - callback id
+  Output Parameter:
+. id - callback id
 
-   Level: developer
+  Level: developer
 
-.seealso: `PetscFortranCallbackGetSizes()`
+.seealso: `PetscFortranCallbackGetSizes()`, `PetscObjectCopyFortranFunctionPointers()`, `PetscObjectSetFortranCallback()`, `PetscObjectGetFortranCallback()`
 @*/
 PetscErrorCode PetscFortranCallbackRegister(PetscClassId classid, const char *subtype, PetscFortranCallbackId *id)
 {
@@ -56,8 +56,8 @@ PetscErrorCode PetscFortranCallbackRegister(PetscClassId classid, const char *su
   FortranCallbackLink  link;
 
   PetscFunctionBegin;
-  if (subtype) PetscValidCharPointer(subtype, 2);
-  PetscValidPointer(id, 3);
+  if (subtype) PetscAssertPointer(subtype, 2);
+  PetscAssertPointer(id, 3);
   PetscCheck(classid >= PETSC_SMALLEST_CLASSID && classid <= PETSC_LARGEST_CLASSID, PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "ClassId %d corrupt", classid);
   *id = 0;
   if (classid >= _maxclassid) {
@@ -98,26 +98,26 @@ PetscErrorCode PetscFortranCallbackRegister(PetscClassId classid, const char *su
 }
 
 /*@C
-   PetscFortranCallbackGetSizes - get sizes of class and subtype pointer arrays
+  PetscFortranCallbackGetSizes - get sizes of class and subtype pointer arrays
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  classid - class Id
+  Input Parameter:
+. classid - class Id
 
-   Output Parameters:
-+  numbase - number of registered class callbacks
--  numsubtype - max number of registered subtype callbacks
+  Output Parameters:
++ numbase    - number of registered class callbacks
+- numsubtype - max number of registered subtype callbacks
 
-   Level: developer
+  Level: developer
 
-.seealso: `PetscFortranCallbackRegister()`
+.seealso: `PetscFortranCallbackRegister()`, `PetscObjectCopyFortranFunctionPointers()`, `PetscObjectSetFortranCallback()`, `PetscObjectGetFortranCallback()`
 @*/
 PetscErrorCode PetscFortranCallbackGetSizes(PetscClassId classid, PetscFortranCallbackId *numbase, PetscFortranCallbackId *numsubtype)
 {
   PetscFunctionBegin;
-  PetscValidPointer(numbase, 2);
-  PetscValidPointer(numsubtype, 3);
+  PetscAssertPointer(numbase, 2);
+  PetscAssertPointer(numsubtype, 3);
   if (classid < _maxclassid) {
     FortranCallbackBase *base = &_classbase[classid - PETSC_SMALLEST_CLASSID];
     *numbase                  = base->basecount;
