@@ -1,27 +1,26 @@
-
 /*
      Provides utility routines for manulating any type of PETSc object.
 */
 #include <petsc/private/petscimpl.h> /*I   "petscsys.h"    I*/
 
 /*@C
-   PetscObjectGetOptions - Gets the options database used by the object that has been set with `PetscObjectSetOptions()`
+  PetscObjectGetOptions - Gets the options database used by the object that has been set with `PetscObjectSetOptions()`
 
-   Collective
+  Collective
 
-   Input Parameter:
-.  obj - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
+  Input Parameter:
+. obj - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
 
-   Output Parameter:
-.  options - the options database
+  Output Parameter:
+. options - the options database
 
   Level: advanced
 
-   Note:
-   If this is not called the object will use the default options database
+  Note:
+  If this is not called the object will use the default options database
 
-   Developer Note:
-   This functionality is not used in PETSc and should, perhaps, be removed
+  Developer Notes:
+  This functionality is not used in PETSc and should, perhaps, be removed
 
 .seealso: `PetscOptionsCreate()`, `PetscOptionsDestroy()`, `PetscObjectSetOptionsPrefix()`, `PetscObjectAppendOptionsPrefix()`, `PetscObjectPrependOptionsPrefix()`,
           `PetscObjectGetOptionsPrefix()`, `PetscObjectSetOptions()`
@@ -35,21 +34,21 @@ PetscErrorCode PetscObjectGetOptions(PetscObject obj, PetscOptions *options)
 }
 
 /*@C
-   PetscObjectSetOptions - Sets the options database used by the object. Call immediately after creating the object.
+  PetscObjectSetOptions - Sets the options database used by the object. Call immediately after creating the object.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  obj - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
--  options - the options database, use NULL for default
+  Input Parameters:
++ obj     - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
+- options - the options database, use NULL for default
 
   Level: advanced
 
-   Note:
-   If this is not called the object will use the default options database
+  Note:
+  If this is not called the object will use the default options database
 
-   Developer Note:
-   This functionality is not used in PETSc and should, perhaps, be removed
+  Developer Notes:
+  This functionality is not used in PETSc and should, perhaps, be removed
 
 .seealso: `PetscOptionsCreate()`, `PetscOptionsDestroy()`, `PetscObjectSetOptionsPrefix()`, `PetscObjectAppendOptionsPrefix()`, `PetscObjectPrependOptionsPrefix()`,
           `PetscObjectGetOptionsPrefix()`, `PetscObjectGetOptions()`
@@ -63,21 +62,21 @@ PetscErrorCode PetscObjectSetOptions(PetscObject obj, PetscOptions options)
 }
 
 /*@C
-   PetscObjectSetOptionsPrefix - Sets the prefix used for searching for all
-   options for the given object in the database.
+  PetscObjectSetOptionsPrefix - Sets the prefix used for searching for all
+  options for the given object in the database.
 
-   Collective
+  Collective
 
-   Input Parameters:
-+  obj - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
--  prefix - the prefix string to prepend to option requests of the object.
+  Input Parameters:
++ obj    - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
+- prefix - the prefix string to prepend to option requests of the object.
 
   Level: advanced
 
-   Note:
-   A hyphen (-) must NOT be given at the beginning of the prefix name.
-   The first character of all runtime options is AUTOMATICALLY the
-   hyphen.
+  Note:
+  A hyphen (-) must NOT be given at the beginning of the prefix name.
+  The first character of all runtime options is AUTOMATICALLY the
+  hyphen.
 
 .seealso: `PetscOptionsCreate()`, `PetscOptionsDestroy()`, `PetscObjectAppendOptionsPrefix()`, `PetscObjectPrependOptionsPrefix()`,
           `PetscObjectGetOptionsPrefix()`, `TSSetOptionsPrefix()`, `SNESSetOptionsPrefix()`, `KSPSetOptionsPrefix()`
@@ -87,7 +86,7 @@ PetscErrorCode PetscObjectSetOptionsPrefix(PetscObject obj, const char prefix[])
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
   if (prefix) {
-    PetscValidCharPointer(prefix, 2);
+    PetscAssertPointer(prefix, 2);
     PetscCheck(prefix[0] != '-', PETSC_COMM_SELF, PETSC_ERR_ARG_WRONG, "Options prefix should not begin with a hyphen");
     if (prefix != obj->prefix) {
       PetscCall(PetscFree(obj->prefix));
@@ -98,19 +97,19 @@ PetscErrorCode PetscObjectSetOptionsPrefix(PetscObject obj, const char prefix[])
 }
 
 /*@C
-   PetscObjectAppendOptionsPrefix - Appends to the prefix used for searching for options for the given object in the database.
+  PetscObjectAppendOptionsPrefix - Appends to the prefix used for searching for options for the given object in the database.
 
-   Input Parameters:
-+  obj - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
--  prefix - the prefix string to prepend to option requests of the object.
-
-   Note:
-   A hyphen (-) must NOT be given at the beginning of the prefix name.
-   The first character of all runtime options is AUTOMATICALLY the
-   hyphen.
+  Input Parameters:
++ obj    - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
+- prefix - the prefix string to prepend to option requests of the object.
 
   Level: advanced
 
+  Note:
+  A hyphen (-) must NOT be given at the beginning of the prefix name.
+  The first character of all runtime options is AUTOMATICALLY the
+  hyphen.
+
 .seealso: `PetscOptionsCreate()`, `PetscOptionsDestroy()`, `PetscObjectSetOptionsPrefix()`, `PetscObjectPrependOptionsPrefix()`,
           `PetscObjectGetOptionsPrefix()`, `TSAppendOptionsPrefix()`, `SNESAppendOptionsPrefix()`, `KSPAppendOptionsPrefix()`
 @*/
@@ -136,13 +135,13 @@ PetscErrorCode PetscObjectAppendOptionsPrefix(PetscObject obj, const char prefix
 }
 
 /*@C
-   PetscObjectGetOptionsPrefix - Gets the prefix of the `PetscObject` used for searching in the options database
+  PetscObjectGetOptionsPrefix - Gets the prefix of the `PetscObject` used for searching in the options database
 
-   Input Parameter:
-.  obj - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
+  Input Parameter:
+. obj - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
 
-   Output Parameter:
-.  prefix - pointer to the prefix string used is returned
+  Output Parameter:
+. prefix - pointer to the prefix string used is returned
 
   Level: advanced
 
@@ -153,26 +152,26 @@ PetscErrorCode PetscObjectGetOptionsPrefix(PetscObject obj, const char *prefix[]
 {
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
-  PetscValidPointer(prefix, 2);
+  PetscAssertPointer(prefix, 2);
   *prefix = obj->prefix;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscObjectPrependOptionsPrefix - Sets the prefix used for searching for options of for this object in the database.
+  PetscObjectPrependOptionsPrefix - Sets the prefix used for searching for options of for this object in the database.
 
-   Input Parameters:
-+  obj - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
--  prefix - the prefix string to prepend to option requests of the object.
-
-   Note:
-   A hyphen (-) must NOT be given at the beginning of the prefix name.
-   The first character of all runtime options is AUTOMATICALLY the
-   hyphen.
+  Input Parameters:
++ obj    - any PETSc object, for example a `Vec`, `Mat` or `KSP`.
+- prefix - the prefix string to prepend to option requests of the object.
 
   Level: advanced
 
-.seealso: `PetscOptionsCreate()`, `PetscOptionsDestroy()`, `PetscObjectSetOptionsPrefix()`, `PetscObjectAppendOptionsPrefix()`,
+  Note:
+  A hyphen (-) must NOT be given at the beginning of the prefix name.
+  The first character of all runtime options is AUTOMATICALLY the
+  hyphen.
+
+  .seealso: `PetscOptionsCreate()`, `PetscOptionsDestroy()`, `PetscObjectSetOptionsPrefix()`, `PetscObjectAppendOptionsPrefix()`,
           `PetscObjectGetOptionsPrefix()`
 @*/
 PetscErrorCode PetscObjectPrependOptionsPrefix(PetscObject obj, const char prefix[])
