@@ -1,5 +1,4 @@
-
-static char help[] ="Tests PetscObjectSetOptions() for TS object\n\n";
+static char help[] = "Tests PetscObjectSetOptions() for TS object\n\n";
 
 /* ------------------------------------------------------------------------
 
@@ -42,51 +41,52 @@ static char help[] ="Tests PetscObjectSetOptions() for TS object\n\n";
    application-provided callback routines.
 */
 typedef struct {
-  MPI_Comm  comm;           /* communicator */
-  DM        da;             /* distributed array data structure */
-  Vec       localwork;      /* local ghosted work vector */
-  Vec       u_local;        /* local ghosted approximate solution vector */
-  Vec       solution;       /* global exact solution vector */
-  PetscInt  m;              /* total number of grid points */
-  PetscReal h;              /* mesh width: h = 1/(m-1) */
+  MPI_Comm  comm;      /* communicator */
+  DM        da;        /* distributed array data structure */
+  Vec       localwork; /* local ghosted work vector */
+  Vec       u_local;   /* local ghosted approximate solution vector */
+  Vec       solution;  /* global exact solution vector */
+  PetscInt  m;         /* total number of grid points */
+  PetscReal h;         /* mesh width: h = 1/(m-1) */
 } AppCtx;
 
 /*
    User-defined routines, provided below.
 */
-extern PetscErrorCode InitialConditions(Vec,AppCtx*);
-extern PetscErrorCode RHSFunction(TS,PetscReal,Vec,Vec,void*);
-extern PetscErrorCode RHSJacobian(TS,PetscReal,Vec,Mat,Mat,void*);
-extern PetscErrorCode ExactSolution(PetscReal,Vec,AppCtx*);
+extern PetscErrorCode InitialConditions(Vec, AppCtx *);
+extern PetscErrorCode RHSFunction(TS, PetscReal, Vec, Vec, void *);
+extern PetscErrorCode RHSJacobian(TS, PetscReal, Vec, Mat, Mat, void *);
+extern PetscErrorCode ExactSolution(PetscReal, Vec, AppCtx *);
 
-int main(int argc,char **argv)
+int main(int argc, char **argv)
 {
-  AppCtx         appctx;                 /* user-defined application context */
-  TS             ts;                     /* timestepping context */
-  Mat            A;                      /* Jacobian matrix data structure */
-  Vec            u;                      /* approximate solution vector */
-  PetscInt       time_steps_max = 100;  /* default max timesteps */
-  PetscReal      dt;
-  PetscReal      time_total_max = 100.0; /* default max total time */
-  PetscOptions   options,optionscopy;
+  AppCtx       appctx;               /* user-defined application context */
+  TS           ts;                   /* timestepping context */
+  Mat          A;                    /* Jacobian matrix data structure */
+  Vec          u;                    /* approximate solution vector */
+  PetscInt     time_steps_max = 100; /* default max timesteps */
+  PetscReal    dt;
+  PetscReal    time_total_max = 100.0; /* default max total time */
+  PetscOptions options, optionscopy;
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Initialize program and set problem parameters
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(PetscInitialize(&argc,&argv,(char*)0,help));
+  PetscFunctionBeginUser;
+  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
 
   PetscCall(PetscOptionsCreate(&options));
-  PetscCall(PetscOptionsSetValue(options,"-ts_monitor","ascii"));
-  PetscCall(PetscOptionsSetValue(options,"-snes_monitor","ascii"));
-  PetscCall(PetscOptionsSetValue(options,"-ksp_monitor","ascii"));
+  PetscCall(PetscOptionsSetValue(options, "-ts_monitor", "ascii"));
+  PetscCall(PetscOptionsSetValue(options, "-snes_monitor", "ascii"));
+  PetscCall(PetscOptionsSetValue(options, "-ksp_monitor", "ascii"));
 
   appctx.comm = PETSC_COMM_WORLD;
   appctx.m    = 60;
 
-  PetscCall(PetscOptionsGetInt(options,NULL,"-M",&appctx.m,NULL));
+  PetscCall(PetscOptionsGetInt(options, NULL, "-M", &appctx.m, NULL));
 
-  appctx.h    = 1.0/(appctx.m-1.0);
+  appctx.h = 1.0 / (appctx.m - 1.0);
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create vector data structures
@@ -97,8 +97,8 @@ int main(int argc,char **argv)
      and to set up the ghost point communication pattern.  There are M
      total grid values spread equally among all the processors.
   */
-  PetscCall(DMDACreate1d(PETSC_COMM_WORLD,DM_BOUNDARY_NONE,appctx.m,1,1,NULL,&appctx.da));
-  PetscCall(PetscObjectSetOptions((PetscObject)appctx.da,options));
+  PetscCall(DMDACreate1d(PETSC_COMM_WORLD, DM_BOUNDARY_NONE, appctx.m, 1, 1, NULL, &appctx.da));
+  PetscCall(PetscObjectSetOptions((PetscObject)appctx.da, options));
   PetscCall(DMSetFromOptions(appctx.da));
   PetscCall(DMSetUp(appctx.da));
 
@@ -107,25 +107,25 @@ int main(int argc,char **argv)
      approximate solution.  Then duplicate these for remaining vectors that
      have the same types.
   */
-  PetscCall(DMCreateGlobalVector(appctx.da,&u));
-  PetscCall(DMCreateLocalVector(appctx.da,&appctx.u_local));
+  PetscCall(DMCreateGlobalVector(appctx.da, &u));
+  PetscCall(DMCreateLocalVector(appctx.da, &appctx.u_local));
 
   /*
      Create local work vector for use in evaluating right-hand-side function;
      create global work vector for storing exact solution.
   */
-  PetscCall(VecDuplicate(appctx.u_local,&appctx.localwork));
-  PetscCall(VecDuplicate(u,&appctx.solution));
+  PetscCall(VecDuplicate(appctx.u_local, &appctx.localwork));
+  PetscCall(VecDuplicate(u, &appctx.solution));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create timestepping solver context; set callback routine for
      right-hand-side function evaluation.
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(TSCreate(PETSC_COMM_WORLD,&ts));
-  PetscCall(PetscObjectSetOptions((PetscObject)ts,options));
-  PetscCall(TSSetProblemType(ts,TS_NONLINEAR));
-  PetscCall(TSSetRHSFunction(ts,NULL,RHSFunction,&appctx));
+  PetscCall(TSCreate(PETSC_COMM_WORLD, &ts));
+  PetscCall(PetscObjectSetOptions((PetscObject)ts, options));
+  PetscCall(TSSetProblemType(ts, TS_NONLINEAR));
+  PetscCall(TSSetRHSFunction(ts, NULL, RHSFunction, &appctx));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      For nonlinear problems, the user can provide a Jacobian evaluation
@@ -134,19 +134,19 @@ int main(int argc,char **argv)
      Create matrix data structure; set Jacobian evaluation routine.
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(MatCreate(PETSC_COMM_WORLD,&A));
-  PetscCall(PetscObjectSetOptions((PetscObject)A,options));
-  PetscCall(MatSetSizes(A,PETSC_DECIDE,PETSC_DECIDE,appctx.m,appctx.m));
+  PetscCall(MatCreate(PETSC_COMM_WORLD, &A));
+  PetscCall(PetscObjectSetOptions((PetscObject)A, options));
+  PetscCall(MatSetSizes(A, PETSC_DECIDE, PETSC_DECIDE, appctx.m, appctx.m));
   PetscCall(MatSetFromOptions(A));
   PetscCall(MatSetUp(A));
-  PetscCall(TSSetRHSJacobian(ts,A,A,RHSJacobian,&appctx));
+  PetscCall(TSSetRHSJacobian(ts, A, A, RHSJacobian, &appctx));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Set solution vector and initial timestep
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  dt   = appctx.h/2.0;
-  PetscCall(TSSetTimeStep(ts,dt));
+  dt = appctx.h / 2.0;
+  PetscCall(TSSetTimeStep(ts, dt));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Customize timestepping solver:
@@ -158,10 +158,10 @@ int main(int argc,char **argv)
      to override the defaults set by TSSetMaxSteps()/TSSetMaxTime().
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(TSSetType(ts,TSBEULER));
-  PetscCall(TSSetMaxSteps(ts,time_steps_max));
-  PetscCall(TSSetMaxTime(ts,time_total_max));
-  PetscCall(TSSetExactFinalTime(ts,TS_EXACTFINALTIME_STEPOVER));
+  PetscCall(TSSetType(ts, TSBEULER));
+  PetscCall(TSSetMaxSteps(ts, time_steps_max));
+  PetscCall(TSSetMaxTime(ts, time_total_max));
+  PetscCall(TSSetExactFinalTime(ts, TS_EXACTFINALTIME_STEPOVER));
   PetscCall(TSSetFromOptions(ts));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -171,20 +171,20 @@ int main(int argc,char **argv)
   /*
      Evaluate initial conditions
   */
-  PetscCall(InitialConditions(u,&appctx));
+  PetscCall(InitialConditions(u, &appctx));
 
   /*
      Run the timestepping solver
   */
-  PetscCall(TSSolve(ts,u));
+  PetscCall(TSSolve(ts, u));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Free work space.  All PETSc objects should be destroyed when they
      are no longer needed.
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(PetscObjectGetOptions((PetscObject)ts,&optionscopy));
-  PetscCheck(options == optionscopy,PETSC_COMM_WORLD,PETSC_ERR_PLIB,"PetscObjectGetOptions() failed");
+  PetscCall(PetscObjectGetOptions((PetscObject)ts, &optionscopy));
+  PetscCheck(options == optionscopy, PETSC_COMM_WORLD, PETSC_ERR_PLIB, "PetscObjectGetOptions() failed");
 
   PetscCall(TSDestroy(&ts));
   PetscCall(VecDestroy(&u));
@@ -215,16 +215,17 @@ int main(int argc,char **argv)
    Output Parameter:
    u - vector with solution at initial time (global)
 */
-PetscErrorCode InitialConditions(Vec u,AppCtx *appctx)
+PetscErrorCode InitialConditions(Vec u, AppCtx *appctx)
 {
-  PetscScalar    *u_localptr,h = appctx->h,x;
-  PetscInt       i,mybase,myend;
+  PetscScalar *u_localptr, h = appctx->h, x;
+  PetscInt     i, mybase, myend;
 
+  PetscFunctionBeginUser;
   /*
      Determine starting point of each processor's range of
      grid values.
   */
-  PetscCall(VecGetOwnershipRange(u,&mybase,&myend));
+  PetscCall(VecGetOwnershipRange(u, &mybase, &myend));
 
   /*
     Get a pointer to vector data.
@@ -235,24 +236,24 @@ PetscErrorCode InitialConditions(Vec u,AppCtx *appctx)
     - Note that the Fortran interface to VecGetArray() differs from the
       C version.  See the users manual for details.
   */
-  PetscCall(VecGetArray(u,&u_localptr));
+  PetscCall(VecGetArray(u, &u_localptr));
 
   /*
      We initialize the solution array by simply writing the solution
      directly into the array locations.  Alternatively, we could use
      VecSetValues() or VecSetValuesLocal().
   */
-  for (i=mybase; i<myend; i++) {
-    x = h*(PetscReal)i; /* current location in global grid */
-    u_localptr[i-mybase] = 1.0 + x*x;
+  for (i = mybase; i < myend; i++) {
+    x                      = h * (PetscReal)i; /* current location in global grid */
+    u_localptr[i - mybase] = 1.0 + x * x;
   }
 
   /*
      Restore vector
   */
-  PetscCall(VecRestoreArray(u,&u_localptr));
+  PetscCall(VecRestoreArray(u, &u_localptr));
 
-  return 0;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /* --------------------------------------------------------------------- */
 /*
@@ -266,36 +267,37 @@ PetscErrorCode InitialConditions(Vec u,AppCtx *appctx)
    Output Parameter:
    solution - vector with the newly computed exact solution
 */
-PetscErrorCode ExactSolution(PetscReal t,Vec solution,AppCtx *appctx)
+PetscErrorCode ExactSolution(PetscReal t, Vec solution, AppCtx *appctx)
 {
-  PetscScalar    *s_localptr,h = appctx->h,x;
-  PetscInt       i,mybase,myend;
+  PetscScalar *s_localptr, h = appctx->h, x;
+  PetscInt     i, mybase, myend;
 
+  PetscFunctionBeginUser;
   /*
      Determine starting and ending points of each processor's
      range of grid values
   */
-  PetscCall(VecGetOwnershipRange(solution,&mybase,&myend));
+  PetscCall(VecGetOwnershipRange(solution, &mybase, &myend));
 
   /*
      Get a pointer to vector data.
   */
-  PetscCall(VecGetArray(solution,&s_localptr));
+  PetscCall(VecGetArray(solution, &s_localptr));
 
   /*
      Simply write the solution directly into the array locations.
      Alternatively, we could use VecSetValues() or VecSetValuesLocal().
   */
-  for (i=mybase; i<myend; i++) {
-    x = h*(PetscReal)i;
-    s_localptr[i-mybase] = (t + 1.0)*(1.0 + x*x);
+  for (i = mybase; i < myend; i++) {
+    x                      = h * (PetscReal)i;
+    s_localptr[i - mybase] = (t + 1.0) * (1.0 + x * x);
   }
 
   /*
      Restore vector
   */
-  PetscCall(VecRestoreArray(solution,&s_localptr));
-  return 0;
+  PetscCall(VecRestoreArray(solution, &s_localptr));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /* --------------------------------------------------------------------- */
 /*
@@ -314,17 +316,18 @@ PetscErrorCode ExactSolution(PetscReal t,Vec solution,AppCtx *appctx)
    Output Parameter:
    global_out - vector containing the newly evaluated function
 */
-PetscErrorCode RHSFunction(TS ts,PetscReal t,Vec global_in,Vec global_out,void *ctx)
+PetscErrorCode RHSFunction(TS ts, PetscReal t, Vec global_in, Vec global_out, void *ctx)
 {
-  AppCtx            *appctx   = (AppCtx*) ctx;     /* user-defined application context */
-  DM                da        = appctx->da;        /* distributed array */
-  Vec               local_in  = appctx->u_local;   /* local ghosted input vector */
-  Vec               localwork = appctx->localwork; /* local ghosted work vector */
-  PetscInt          i,localsize;
-  PetscMPIInt       rank,size;
-  PetscScalar       *copyptr,sc;
+  AppCtx            *appctx    = (AppCtx *)ctx;     /* user-defined application context */
+  DM                 da        = appctx->da;        /* distributed array */
+  Vec                local_in  = appctx->u_local;   /* local ghosted input vector */
+  Vec                localwork = appctx->localwork; /* local ghosted work vector */
+  PetscInt           i, localsize;
+  PetscMPIInt        rank, size;
+  PetscScalar       *copyptr, sc;
   const PetscScalar *localptr;
 
+  PetscFunctionBeginUser;
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Get ready for local function computations
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
@@ -334,25 +337,25 @@ PetscErrorCode RHSFunction(TS ts,PetscReal t,Vec global_in,Vec global_out,void *
      By placing code between these two statements, computations can be
      done while messages are in transition.
   */
-  PetscCall(DMGlobalToLocalBegin(da,global_in,INSERT_VALUES,local_in));
-  PetscCall(DMGlobalToLocalEnd(da,global_in,INSERT_VALUES,local_in));
+  PetscCall(DMGlobalToLocalBegin(da, global_in, INSERT_VALUES, local_in));
+  PetscCall(DMGlobalToLocalEnd(da, global_in, INSERT_VALUES, local_in));
 
   /*
       Access directly the values in our local INPUT work array
   */
-  PetscCall(VecGetArrayRead(local_in,&localptr));
+  PetscCall(VecGetArrayRead(local_in, &localptr));
 
   /*
       Access directly the values in our local OUTPUT work array
   */
-  PetscCall(VecGetArray(localwork,&copyptr));
+  PetscCall(VecGetArray(localwork, &copyptr));
 
-  sc = 1.0/(appctx->h*appctx->h*2.0*(1.0+t)*(1.0+t));
+  sc = 1.0 / (appctx->h * appctx->h * 2.0 * (1.0 + t) * (1.0 + t));
 
   /*
       Evaluate our function on the nodes owned by this processor
   */
-  PetscCall(VecGetLocalSize(local_in,&localsize));
+  PetscCall(VecGetLocalSize(local_in, &localsize));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Compute entries for the locally owned part
@@ -367,31 +370,31 @@ PetscErrorCode RHSFunction(TS ts,PetscReal t,Vec global_in,Vec global_out,void *
      In our case, u(t,0) = t + 1, so that u_{t}(t,0) = 1
              and  u(t,1) = 2t+ 2, so that u_{t}(t,1) = 2
   */
-  PetscCallMPI(MPI_Comm_rank(appctx->comm,&rank));
-  PetscCallMPI(MPI_Comm_size(appctx->comm,&size));
-  if (rank == 0)          copyptr[0]           = 1.0;
-  if (rank == size-1) copyptr[localsize-1] = 2.0;
+  PetscCallMPI(MPI_Comm_rank(appctx->comm, &rank));
+  PetscCallMPI(MPI_Comm_size(appctx->comm, &size));
+  if (rank == 0) copyptr[0] = 1.0;
+  if (rank == size - 1) copyptr[localsize - 1] = 2.0;
 
   /*
      Handle the interior nodes where the PDE is replace by finite
      difference operators.
   */
-  for (i=1; i<localsize-1; i++) copyptr[i] =  localptr[i] * sc * (localptr[i+1] + localptr[i-1] - 2.0*localptr[i]);
+  for (i = 1; i < localsize - 1; i++) copyptr[i] = localptr[i] * sc * (localptr[i + 1] + localptr[i - 1] - 2.0 * localptr[i]);
 
   /*
      Restore vectors
   */
-  PetscCall(VecRestoreArrayRead(local_in,&localptr));
-  PetscCall(VecRestoreArray(localwork,&copyptr));
+  PetscCall(VecRestoreArrayRead(local_in, &localptr));
+  PetscCall(VecRestoreArray(localwork, &copyptr));
 
   /*
      Insert values from the local OUTPUT vector into the global
      output vector
   */
-  PetscCall(DMLocalToGlobalBegin(da,localwork,INSERT_VALUES,global_out));
-  PetscCall(DMLocalToGlobalEnd(da,localwork,INSERT_VALUES,global_out));
+  PetscCall(DMLocalToGlobalBegin(da, localwork, INSERT_VALUES, global_out));
+  PetscCall(DMLocalToGlobalEnd(da, localwork, INSERT_VALUES, global_out));
 
-  return 0;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /* --------------------------------------------------------------------- */
 /*
@@ -422,15 +425,16 @@ PetscErrorCode RHSFunction(TS ts,PetscReal t,Vec global_in,Vec global_out,void *
    - Note that MatSetValues() uses 0-based row and column numbers
      in Fortran as well as in C.
 */
-PetscErrorCode RHSJacobian(TS ts,PetscReal t,Vec global_in,Mat AA,Mat BB,void *ctx)
+PetscErrorCode RHSJacobian(TS ts, PetscReal t, Vec global_in, Mat AA, Mat BB, void *ctx)
 {
-  AppCtx            *appctx  = (AppCtx*)ctx;    /* user-defined application context */
-  Vec               local_in = appctx->u_local;   /* local ghosted input vector */
-  DM                da       = appctx->da;        /* distributed array */
-  PetscScalar       v[3],sc;
+  AppCtx            *appctx   = (AppCtx *)ctx;   /* user-defined application context */
+  Vec                local_in = appctx->u_local; /* local ghosted input vector */
+  DM                 da       = appctx->da;      /* distributed array */
+  PetscScalar        v[3], sc;
   const PetscScalar *localptr;
-  PetscInt          i,mstart,mend,mstarts,mends,idx[3],is;
+  PetscInt           i, mstart, mend, mstarts, mends, idx[3], is;
 
+  PetscFunctionBeginUser;
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Get ready for local Jacobian computations
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
@@ -440,19 +444,20 @@ PetscErrorCode RHSJacobian(TS ts,PetscReal t,Vec global_in,Mat AA,Mat BB,void *c
      By placing code between these two statements, computations can be
      done while messages are in transition.
   */
-  PetscCall(DMGlobalToLocalBegin(da,global_in,INSERT_VALUES,local_in));
-  PetscCall(DMGlobalToLocalEnd(da,global_in,INSERT_VALUES,local_in));
+  PetscCall(DMGlobalToLocalBegin(da, global_in, INSERT_VALUES, local_in));
+  PetscCall(DMGlobalToLocalEnd(da, global_in, INSERT_VALUES, local_in));
 
   /*
      Get pointer to vector data
   */
-  PetscCall(VecGetArrayRead(local_in,&localptr));
+  PetscCall(VecGetArrayRead(local_in, &localptr));
 
   /*
      Get starting and ending locally owned rows of the matrix
   */
-  PetscCall(MatGetOwnershipRange(BB,&mstarts,&mends));
-  mstart = mstarts; mend = mends;
+  PetscCall(MatGetOwnershipRange(BB, &mstarts, &mends));
+  mstart = mstarts;
+  mend   = mends;
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Compute entries for the locally owned part of the Jacobian.
@@ -471,33 +476,35 @@ PetscErrorCode RHSJacobian(TS ts,PetscReal t,Vec global_in,Mat AA,Mat BB,void *c
   */
   if (mstart == 0) {
     v[0] = 0.0;
-    PetscCall(MatSetValues(BB,1,&mstart,1,&mstart,v,INSERT_VALUES));
+    PetscCall(MatSetValues(BB, 1, &mstart, 1, &mstart, v, INSERT_VALUES));
     mstart++;
   }
   if (mend == appctx->m) {
     mend--;
     v[0] = 0.0;
-    PetscCall(MatSetValues(BB,1,&mend,1,&mend,v,INSERT_VALUES));
+    PetscCall(MatSetValues(BB, 1, &mend, 1, &mend, v, INSERT_VALUES));
   }
 
   /*
      Set matrix rows corresponding to interior data.  We construct the
      matrix one row at a time.
   */
-  sc = 1.0/(appctx->h*appctx->h*2.0*(1.0+t)*(1.0+t));
-  for (i=mstart; i<mend; i++) {
-    idx[0] = i-1; idx[1] = i; idx[2] = i+1;
+  sc = 1.0 / (appctx->h * appctx->h * 2.0 * (1.0 + t) * (1.0 + t));
+  for (i = mstart; i < mend; i++) {
+    idx[0] = i - 1;
+    idx[1] = i;
+    idx[2] = i + 1;
     is     = i - mstart + 1;
-    v[0]   = sc*localptr[is];
-    v[1]   = sc*(localptr[is+1] + localptr[is-1] - 4.0*localptr[is]);
-    v[2]   = sc*localptr[is];
-    PetscCall(MatSetValues(BB,1,&i,3,idx,v,INSERT_VALUES));
+    v[0]   = sc * localptr[is];
+    v[1]   = sc * (localptr[is + 1] + localptr[is - 1] - 4.0 * localptr[is]);
+    v[2]   = sc * localptr[is];
+    PetscCall(MatSetValues(BB, 1, &i, 3, idx, v, INSERT_VALUES));
   }
 
   /*
      Restore vector
   */
-  PetscCall(VecRestoreArrayRead(local_in,&localptr));
+  PetscCall(VecRestoreArrayRead(local_in, &localptr));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Complete the matrix assembly process and set some options
@@ -508,20 +515,20 @@ PetscErrorCode RHSJacobian(TS ts,PetscReal t,Vec global_in,Mat AA,Mat BB,void *c
      Computations can be done while messages are in transition
      by placing code between these two statements.
   */
-  PetscCall(MatAssemblyBegin(BB,MAT_FINAL_ASSEMBLY));
-  PetscCall(MatAssemblyEnd(BB,MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyBegin(BB, MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyEnd(BB, MAT_FINAL_ASSEMBLY));
   if (BB != AA) {
-    PetscCall(MatAssemblyBegin(AA,MAT_FINAL_ASSEMBLY));
-    PetscCall(MatAssemblyEnd(AA,MAT_FINAL_ASSEMBLY));
+    PetscCall(MatAssemblyBegin(AA, MAT_FINAL_ASSEMBLY));
+    PetscCall(MatAssemblyEnd(AA, MAT_FINAL_ASSEMBLY));
   }
 
   /*
      Set and option to indicate that we will never add a new nonzero location
      to the matrix. If we do, it will generate an error.
   */
-  PetscCall(MatSetOption(BB,MAT_NEW_NONZERO_LOCATION_ERR,PETSC_TRUE));
+  PetscCall(MatSetOption(BB, MAT_NEW_NONZERO_LOCATION_ERR, PETSC_TRUE));
 
-  return 0;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*TEST
