@@ -1,5 +1,4 @@
-
-static char help[] ="Solves a simple time-dependent linear PDE (the heat equation).\n\
+static char help[] = "Solves a simple time-dependent linear PDE (the heat equation).\n\
 Input parameters include:\n\
   -m <points>, where <points> = number of grid points\n\
   -time_dependent_rhs : Treat the problem as having a time-dependent right-hand side\n\
@@ -57,60 +56,61 @@ Input parameters include:\n\
    application-provided call-back routines.
 */
 typedef struct {
-  Vec         solution;          /* global exact solution vector */
-  PetscInt    m;                 /* total number of grid points */
-  PetscReal   h;                 /* mesh width h = 1/(m-1) */
-  PetscBool   debug;             /* flag (1 indicates activation of debugging printouts) */
-  PetscViewer viewer1,viewer2;   /* viewers for the solution and error */
-  PetscReal   norm_2,norm_max;   /* error norms */
-  Mat         A;                 /* RHS mat, used with IFunction interface */
-  PetscReal   oshift;            /* old shift applied, prevent to recompute the IJacobian */
+  Vec         solution;         /* global exact solution vector */
+  PetscInt    m;                /* total number of grid points */
+  PetscReal   h;                /* mesh width h = 1/(m-1) */
+  PetscBool   debug;            /* flag (1 indicates activation of debugging printouts) */
+  PetscViewer viewer1, viewer2; /* viewers for the solution and error */
+  PetscReal   norm_2, norm_max; /* error norms */
+  Mat         A;                /* RHS mat, used with IFunction interface */
+  PetscReal   oshift;           /* old shift applied, prevent to recompute the IJacobian */
 } AppCtx;
 
 /*
    User-defined routines
 */
-extern PetscErrorCode InitialConditions(Vec,AppCtx*);
-extern PetscErrorCode RHSMatrixHeat(TS,PetscReal,Vec,Mat,Mat,void*);
-extern PetscErrorCode IFunctionHeat(TS,PetscReal,Vec,Vec,Vec,void*);
-extern PetscErrorCode IJacobianHeat(TS,PetscReal,Vec,Vec,PetscReal,Mat,Mat,void*);
-extern PetscErrorCode Monitor(TS,PetscInt,PetscReal,Vec,void*);
-extern PetscErrorCode ExactSolution(PetscReal,Vec,AppCtx*);
+extern PetscErrorCode InitialConditions(Vec, AppCtx *);
+extern PetscErrorCode RHSMatrixHeat(TS, PetscReal, Vec, Mat, Mat, void *);
+extern PetscErrorCode IFunctionHeat(TS, PetscReal, Vec, Vec, Vec, void *);
+extern PetscErrorCode IJacobianHeat(TS, PetscReal, Vec, Vec, PetscReal, Mat, Mat, void *);
+extern PetscErrorCode Monitor(TS, PetscInt, PetscReal, Vec, void *);
+extern PetscErrorCode ExactSolution(PetscReal, Vec, AppCtx *);
 
-int main(int argc,char **argv)
+int main(int argc, char **argv)
 {
-  AppCtx         appctx;                 /* user-defined application context */
-  TS             ts;                     /* timestepping context */
-  Mat            A;                      /* matrix data structure */
-  Vec            u;                      /* approximate solution vector */
-  PetscReal      time_total_max = 100.0; /* default max total time */
-  PetscInt       time_steps_max = 100;   /* default max timesteps */
-  PetscDraw      draw;                   /* drawing context */
-  PetscInt       steps,m;
-  PetscMPIInt    size;
-  PetscReal      dt;
-  PetscBool      flg,flg_string;
+  AppCtx      appctx;                 /* user-defined application context */
+  TS          ts;                     /* timestepping context */
+  Mat         A;                      /* matrix data structure */
+  Vec         u;                      /* approximate solution vector */
+  PetscReal   time_total_max = 100.0; /* default max total time */
+  PetscInt    time_steps_max = 100;   /* default max timesteps */
+  PetscDraw   draw;                   /* drawing context */
+  PetscInt    steps, m;
+  PetscMPIInt size;
+  PetscReal   dt;
+  PetscBool   flg, flg_string;
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Initialize program and set problem parameters
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(PetscInitialize(&argc,&argv,(char*)0,help));
-  PetscCallMPI(MPI_Comm_size(PETSC_COMM_WORLD,&size));
-  PetscCheck(size == 1,PETSC_COMM_WORLD,PETSC_ERR_WRONG_MPI_SIZE,"This is a uniprocessor example only!");
+  PetscFunctionBeginUser;
+  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
+  PetscCallMPI(MPI_Comm_size(PETSC_COMM_WORLD, &size));
+  PetscCheck(size == 1, PETSC_COMM_WORLD, PETSC_ERR_WRONG_MPI_SIZE, "This is a uniprocessor example only!");
 
-  m    = 60;
-  PetscCall(PetscOptionsGetInt(NULL,NULL,"-m",&m,NULL));
-  PetscCall(PetscOptionsHasName(NULL,NULL,"-debug",&appctx.debug));
+  m = 60;
+  PetscCall(PetscOptionsGetInt(NULL, NULL, "-m", &m, NULL));
+  PetscCall(PetscOptionsHasName(NULL, NULL, "-debug", &appctx.debug));
   flg_string = PETSC_FALSE;
-  PetscCall(PetscOptionsGetBool(NULL,NULL,"-test_string_viewer",&flg_string,NULL));
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-test_string_viewer", &flg_string, NULL));
 
   appctx.m        = m;
-  appctx.h        = 1.0/(m-1.0);
+  appctx.h        = 1.0 / (m - 1.0);
   appctx.norm_2   = 0.0;
   appctx.norm_max = 0.0;
 
-  PetscCall(PetscPrintf(PETSC_COMM_SELF,"Solving a linear TS problem on 1 processor\n"));
+  PetscCall(PetscPrintf(PETSC_COMM_SELF, "Solving a linear TS problem on 1 processor\n"));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create vector data structures
@@ -119,58 +119,56 @@ int main(int argc,char **argv)
   /*
      Create vector data structures for approximate and exact solutions
   */
-  PetscCall(VecCreateSeq(PETSC_COMM_SELF,m,&u));
-  PetscCall(VecDuplicate(u,&appctx.solution));
+  PetscCall(VecCreateSeq(PETSC_COMM_SELF, m, &u));
+  PetscCall(VecDuplicate(u, &appctx.solution));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Set up displays to show graphs of the solution and error
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(PetscViewerDrawOpen(PETSC_COMM_SELF,0,"",80,380,400,160,&appctx.viewer1));
-  PetscCall(PetscViewerDrawGetDraw(appctx.viewer1,0,&draw));
+  PetscCall(PetscViewerDrawOpen(PETSC_COMM_SELF, 0, "", 80, 380, 400, 160, &appctx.viewer1));
+  PetscCall(PetscViewerDrawGetDraw(appctx.viewer1, 0, &draw));
   PetscCall(PetscDrawSetDoubleBuffer(draw));
-  PetscCall(PetscViewerDrawOpen(PETSC_COMM_SELF,0,"",80,0,400,160,&appctx.viewer2));
-  PetscCall(PetscViewerDrawGetDraw(appctx.viewer2,0,&draw));
+  PetscCall(PetscViewerDrawOpen(PETSC_COMM_SELF, 0, "", 80, 0, 400, 160, &appctx.viewer2));
+  PetscCall(PetscViewerDrawGetDraw(appctx.viewer2, 0, &draw));
   PetscCall(PetscDrawSetDoubleBuffer(draw));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create timestepping solver context
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(TSCreate(PETSC_COMM_SELF,&ts));
-  PetscCall(TSSetProblemType(ts,TS_LINEAR));
+  PetscCall(TSCreate(PETSC_COMM_SELF, &ts));
+  PetscCall(TSSetProblemType(ts, TS_LINEAR));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Set optional user-defined monitoring routine
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  if (!flg_string) {
-    PetscCall(TSMonitorSet(ts,Monitor,&appctx,NULL));
-  }
+  if (!flg_string) PetscCall(TSMonitorSet(ts, Monitor, &appctx, NULL));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
      Create matrix data structure; set matrix evaluation routine.
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(MatCreate(PETSC_COMM_SELF,&A));
-  PetscCall(MatSetSizes(A,PETSC_DECIDE,PETSC_DECIDE,m,m));
+  PetscCall(MatCreate(PETSC_COMM_SELF, &A));
+  PetscCall(MatSetSizes(A, PETSC_DECIDE, PETSC_DECIDE, m, m));
   PetscCall(MatSetFromOptions(A));
   PetscCall(MatSetUp(A));
 
-  flg  = PETSC_FALSE;
-  PetscCall(PetscOptionsGetBool(NULL,NULL,"-use_ifunc",&flg,NULL));
+  flg = PETSC_FALSE;
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-use_ifunc", &flg, NULL));
   if (!flg) {
     appctx.A = NULL;
-    PetscCall(PetscOptionsGetBool(NULL,NULL,"-time_dependent_rhs",&flg,NULL));
+    PetscCall(PetscOptionsGetBool(NULL, NULL, "-time_dependent_rhs", &flg, NULL));
     if (flg) {
       /*
          For linear problems with a time-dependent f(u,t) in the equation
          u_t = f(u,t), the user provides the discretized right-hand-side
          as a time-dependent matrix.
       */
-      PetscCall(TSSetRHSFunction(ts,NULL,TSComputeRHSFunctionLinear,&appctx));
-      PetscCall(TSSetRHSJacobian(ts,A,A,RHSMatrixHeat,&appctx));
+      PetscCall(TSSetRHSFunction(ts, NULL, TSComputeRHSFunctionLinear, &appctx));
+      PetscCall(TSSetRHSJacobian(ts, A, A, RHSMatrixHeat, &appctx));
     } else {
       /*
          For linear problems with a time-independent f(u) in the equation
@@ -178,29 +176,29 @@ int main(int argc,char **argv)
          as a matrix only once, and then sets the special Jacobian evaluation
          routine TSComputeRHSJacobianConstant() which will NOT recompute the Jacobian.
       */
-      PetscCall(RHSMatrixHeat(ts,0.0,u,A,A,&appctx));
-      PetscCall(TSSetRHSFunction(ts,NULL,TSComputeRHSFunctionLinear,&appctx));
-      PetscCall(TSSetRHSJacobian(ts,A,A,TSComputeRHSJacobianConstant,&appctx));
+      PetscCall(RHSMatrixHeat(ts, 0.0, u, A, A, &appctx));
+      PetscCall(TSSetRHSFunction(ts, NULL, TSComputeRHSFunctionLinear, &appctx));
+      PetscCall(TSSetRHSJacobian(ts, A, A, TSComputeRHSJacobianConstant, &appctx));
     }
   } else {
     Mat J;
 
-    PetscCall(RHSMatrixHeat(ts,0.0,u,A,A,&appctx));
-    PetscCall(MatDuplicate(A,MAT_DO_NOT_COPY_VALUES,&J));
-    PetscCall(TSSetIFunction(ts,NULL,IFunctionHeat,&appctx));
-    PetscCall(TSSetIJacobian(ts,J,J,IJacobianHeat,&appctx));
+    PetscCall(RHSMatrixHeat(ts, 0.0, u, A, A, &appctx));
+    PetscCall(MatDuplicate(A, MAT_DO_NOT_COPY_VALUES, &J));
+    PetscCall(TSSetIFunction(ts, NULL, IFunctionHeat, &appctx));
+    PetscCall(TSSetIJacobian(ts, J, J, IJacobianHeat, &appctx));
     PetscCall(MatDestroy(&J));
 
     PetscCall(PetscObjectReference((PetscObject)A));
-    appctx.A = A;
+    appctx.A      = A;
     appctx.oshift = PETSC_MIN_REAL;
   }
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Set solution vector and initial timestep
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  dt   = appctx.h*appctx.h/2.0;
-  PetscCall(TSSetTimeStep(ts,dt));
+  dt = appctx.h * appctx.h / 2.0;
+  PetscCall(TSSetTimeStep(ts, dt));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Customize timestepping solver:
@@ -212,9 +210,9 @@ int main(int argc,char **argv)
      to override the defaults set by TSSetMaxSteps()/TSSetMaxTime().
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(TSSetMaxSteps(ts,time_steps_max));
-  PetscCall(TSSetMaxTime(ts,time_total_max));
-  PetscCall(TSSetExactFinalTime(ts,TS_EXACTFINALTIME_STEPOVER));
+  PetscCall(TSSetMaxSteps(ts, time_steps_max));
+  PetscCall(TSSetMaxTime(ts, time_total_max));
+  PetscCall(TSSetExactFinalTime(ts, TS_EXACTFINALTIME_STEPOVER));
   PetscCall(TSSetFromOptions(ts));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -224,31 +222,31 @@ int main(int argc,char **argv)
   /*
      Evaluate initial conditions
   */
-  PetscCall(InitialConditions(u,&appctx));
+  PetscCall(InitialConditions(u, &appctx));
 
   /*
      Run the timestepping solver
   */
-  PetscCall(TSSolve(ts,u));
-  PetscCall(TSGetStepNumber(ts,&steps));
+  PetscCall(TSSolve(ts, u));
+  PetscCall(TSGetStepNumber(ts, &steps));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      View timestepping solver info
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  PetscCall(PetscPrintf(PETSC_COMM_SELF,"avg. error (2 norm) = %g, avg. error (max norm) = %g\n",(double)(appctx.norm_2/steps),(double)(appctx.norm_max/steps)));
+  PetscCall(PetscPrintf(PETSC_COMM_SELF, "avg. error (2 norm) = %g, avg. error (max norm) = %g\n", (double)(appctx.norm_2 / steps), (double)(appctx.norm_max / steps)));
   if (!flg_string) {
-    PetscCall(TSView(ts,PETSC_VIEWER_STDOUT_SELF));
+    PetscCall(TSView(ts, PETSC_VIEWER_STDOUT_SELF));
   } else {
     PetscViewer stringviewer;
     char        string[512];
-    const char  *outstring;
+    const char *outstring;
 
-    PetscCall(PetscViewerStringOpen(PETSC_COMM_WORLD,string,sizeof(string),&stringviewer));
-    PetscCall(TSView(ts,stringviewer));
-    PetscCall(PetscViewerStringGetStringRead(stringviewer,&outstring,NULL));
-    PetscCheck((char*)outstring == (char*)string,PETSC_COMM_WORLD,PETSC_ERR_PLIB,"String returned from viewer does not equal original string");
-    PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Output from string viewer:%s\n",outstring));
+    PetscCall(PetscViewerStringOpen(PETSC_COMM_WORLD, string, sizeof(string), &stringviewer));
+    PetscCall(TSView(ts, stringviewer));
+    PetscCall(PetscViewerStringGetStringRead(stringviewer, &outstring, NULL));
+    PetscCheck((char *)outstring == (char *)string, PETSC_COMM_WORLD, PETSC_ERR_PLIB, "String returned from viewer does not equal original string");
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Output from string viewer:%s\n", outstring));
     PetscCall(PetscViewerDestroy(&stringviewer));
   }
 
@@ -285,11 +283,12 @@ int main(int argc,char **argv)
    Output Parameter:
    u - vector with solution at initial time (global)
 */
-PetscErrorCode InitialConditions(Vec u,AppCtx *appctx)
+PetscErrorCode InitialConditions(Vec u, AppCtx *appctx)
 {
-  PetscScalar    *u_localptr,h = appctx->h;
-  PetscInt       i;
+  PetscScalar *u_localptr, h = appctx->h;
+  PetscInt     i;
 
+  PetscFunctionBeginUser;
   /*
     Get a pointer to vector data.
     - For default PETSc vectors, VecGetArray() returns a pointer to
@@ -299,29 +298,29 @@ PetscErrorCode InitialConditions(Vec u,AppCtx *appctx)
     - Note that the Fortran interface to VecGetArray() differs from the
       C version.  See the users manual for details.
   */
-  PetscCall(VecGetArrayWrite(u,&u_localptr));
+  PetscCall(VecGetArrayWrite(u, &u_localptr));
 
   /*
      We initialize the solution array by simply writing the solution
      directly into the array locations.  Alternatively, we could use
      VecSetValues() or VecSetValuesLocal().
   */
-  for (i=0; i<appctx->m; i++) u_localptr[i] = PetscSinScalar(PETSC_PI*i*6.*h) + 3.*PetscSinScalar(PETSC_PI*i*2.*h);
+  for (i = 0; i < appctx->m; i++) u_localptr[i] = PetscSinScalar(PETSC_PI * i * 6. * h) + 3. * PetscSinScalar(PETSC_PI * i * 2. * h);
 
   /*
      Restore vector
   */
-  PetscCall(VecRestoreArrayWrite(u,&u_localptr));
+  PetscCall(VecRestoreArrayWrite(u, &u_localptr));
 
   /*
      Print debugging information if desired
   */
   if (appctx->debug) {
-    PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Initial guess vector\n"));
-    PetscCall(VecView(u,PETSC_VIEWER_STDOUT_SELF));
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Initial guess vector\n"));
+    PetscCall(VecView(u, PETSC_VIEWER_STDOUT_SELF));
   }
 
-  return 0;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /* --------------------------------------------------------------------- */
 /*
@@ -335,30 +334,32 @@ PetscErrorCode InitialConditions(Vec u,AppCtx *appctx)
    Output Parameter:
    solution - vector with the newly computed exact solution
 */
-PetscErrorCode ExactSolution(PetscReal t,Vec solution,AppCtx *appctx)
+PetscErrorCode ExactSolution(PetscReal t, Vec solution, AppCtx *appctx)
 {
-  PetscScalar    *s_localptr,h = appctx->h,ex1,ex2,sc1,sc2,tc = t;
-  PetscInt       i;
+  PetscScalar *s_localptr, h = appctx->h, ex1, ex2, sc1, sc2, tc = t;
+  PetscInt     i;
 
+  PetscFunctionBeginUser;
   /*
      Get a pointer to vector data.
   */
-  PetscCall(VecGetArrayWrite(solution,&s_localptr));
+  PetscCall(VecGetArrayWrite(solution, &s_localptr));
 
   /*
      Simply write the solution directly into the array locations.
      Alternatively, we culd use VecSetValues() or VecSetValuesLocal().
   */
-  ex1 = PetscExpScalar(-36.*PETSC_PI*PETSC_PI*tc);
-  ex2 = PetscExpScalar(-4.*PETSC_PI*PETSC_PI*tc);
-  sc1 = PETSC_PI*6.*h;                 sc2 = PETSC_PI*2.*h;
-  for (i=0; i<appctx->m; i++) s_localptr[i] = PetscSinScalar(sc1*(PetscReal)i)*ex1 + 3.*PetscSinScalar(sc2*(PetscReal)i)*ex2;
+  ex1 = PetscExpScalar(-36. * PETSC_PI * PETSC_PI * tc);
+  ex2 = PetscExpScalar(-4. * PETSC_PI * PETSC_PI * tc);
+  sc1 = PETSC_PI * 6. * h;
+  sc2 = PETSC_PI * 2. * h;
+  for (i = 0; i < appctx->m; i++) s_localptr[i] = PetscSinScalar(sc1 * (PetscReal)i) * ex1 + 3. * PetscSinScalar(sc2 * (PetscReal)i) * ex2;
 
   /*
      Restore vector
   */
-  PetscCall(VecRestoreArrayWrite(solution,&s_localptr));
-  return 0;
+  PetscCall(VecRestoreArrayWrite(solution, &s_localptr));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /* --------------------------------------------------------------------- */
 /*
@@ -379,66 +380,67 @@ PetscErrorCode ExactSolution(PetscReal t,Vec solution,AppCtx *appctx)
             information about the problem size, workspace and the exact
             solution.
 */
-PetscErrorCode Monitor(TS ts,PetscInt step,PetscReal time,Vec u,void *ctx)
+PetscErrorCode Monitor(TS ts, PetscInt step, PetscReal time, Vec u, void *ctx)
 {
-  AppCtx         *appctx = (AppCtx*) ctx;   /* user-defined application context */
-  PetscReal      norm_2,norm_max,dt,dttol;
+  AppCtx   *appctx = (AppCtx *)ctx; /* user-defined application context */
+  PetscReal norm_2, norm_max, dt, dttol;
 
+  PetscFunctionBeginUser;
   /*
      View a graph of the current iterate
   */
-  PetscCall(VecView(u,appctx->viewer2));
+  PetscCall(VecView(u, appctx->viewer2));
 
   /*
      Compute the exact solution
   */
-  PetscCall(ExactSolution(time,appctx->solution,appctx));
+  PetscCall(ExactSolution(time, appctx->solution, appctx));
 
   /*
      Print debugging information if desired
   */
   if (appctx->debug) {
-    PetscCall(PetscPrintf(PETSC_COMM_SELF,"Computed solution vector\n"));
-    PetscCall(VecView(u,PETSC_VIEWER_STDOUT_SELF));
-    PetscCall(PetscPrintf(PETSC_COMM_SELF,"Exact solution vector\n"));
-    PetscCall(VecView(appctx->solution,PETSC_VIEWER_STDOUT_SELF));
+    PetscCall(PetscPrintf(PETSC_COMM_SELF, "Computed solution vector\n"));
+    PetscCall(VecView(u, PETSC_VIEWER_STDOUT_SELF));
+    PetscCall(PetscPrintf(PETSC_COMM_SELF, "Exact solution vector\n"));
+    PetscCall(VecView(appctx->solution, PETSC_VIEWER_STDOUT_SELF));
   }
 
   /*
      Compute the 2-norm and max-norm of the error
   */
-  PetscCall(VecAXPY(appctx->solution,-1.0,u));
-  PetscCall(VecNorm(appctx->solution,NORM_2,&norm_2));
-  norm_2 = PetscSqrtReal(appctx->h)*norm_2;
-  PetscCall(VecNorm(appctx->solution,NORM_MAX,&norm_max));
+  PetscCall(VecAXPY(appctx->solution, -1.0, u));
+  PetscCall(VecNorm(appctx->solution, NORM_2, &norm_2));
+  norm_2 = PetscSqrtReal(appctx->h) * norm_2;
+  PetscCall(VecNorm(appctx->solution, NORM_MAX, &norm_max));
 
-  PetscCall(TSGetTimeStep(ts,&dt));
-  PetscCall(PetscPrintf(PETSC_COMM_WORLD,"Timestep %3D: step size = %g, time = %g, 2-norm error = %g, max norm error = %g\n",step,(double)dt,(double)time,(double)norm_2,(double)norm_max));
+  PetscCall(TSGetTimeStep(ts, &dt));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Timestep %3" PetscInt_FMT ": step size = %g, time = %g, 2-norm error = %g, max norm error = %g\n", step, (double)dt, (double)time, (double)norm_2, (double)norm_max));
 
-  appctx->norm_2   += norm_2;
+  appctx->norm_2 += norm_2;
   appctx->norm_max += norm_max;
 
   dttol = .0001;
-  PetscCall(PetscOptionsGetReal(NULL,NULL,"-dttol",&dttol,NULL));
+  PetscCall(PetscOptionsGetReal(NULL, NULL, "-dttol", &dttol, NULL));
   if (dt < dttol) {
-    dt  *= .999;
-    PetscCall(TSSetTimeStep(ts,dt));
+    dt *= .999;
+    PetscCall(TSSetTimeStep(ts, dt));
   }
 
   /*
      View a graph of the error
   */
-  PetscCall(VecView(appctx->solution,appctx->viewer1));
+  PetscCall(VecView(appctx->solution, appctx->viewer1));
 
   /*
      Print debugging information if desired
   */
   if (appctx->debug) {
-    PetscCall(PetscPrintf(PETSC_COMM_SELF,"Error vector\n"));
-    PetscCall(VecView(appctx->solution,PETSC_VIEWER_STDOUT_SELF));
+    PetscCall(PetscPrintf(PETSC_COMM_SELF, "Error vector\n"));
+    PetscCall(VecView(appctx->solution, PETSC_VIEWER_STDOUT_SELF));
   }
 
-  return 0;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /* --------------------------------------------------------------------- */
 /*
@@ -460,15 +462,16 @@ PetscErrorCode Monitor(TS ts,PetscInt step,PetscReal time,Vec u,void *ctx)
    Recall that MatSetValues() uses 0-based row and column numbers
    in Fortran as well as in C.
 */
-PetscErrorCode RHSMatrixHeat(TS ts,PetscReal t,Vec X,Mat AA,Mat BB,void *ctx)
+PetscErrorCode RHSMatrixHeat(TS ts, PetscReal t, Vec X, Mat AA, Mat BB, void *ctx)
 {
-  Mat            A       = AA;                /* Jacobian matrix */
-  AppCtx         *appctx = (AppCtx*)ctx;     /* user-defined application context */
-  PetscInt       mstart  = 0;
-  PetscInt       mend    = appctx->m;
-  PetscInt       i,idx[3];
-  PetscScalar    v[3],stwo = -2./(appctx->h*appctx->h),sone = -.5*stwo;
+  Mat         A      = AA;            /* Jacobian matrix */
+  AppCtx     *appctx = (AppCtx *)ctx; /* user-defined application context */
+  PetscInt    mstart = 0;
+  PetscInt    mend   = appctx->m;
+  PetscInt    i, idx[3];
+  PetscScalar v[3], stwo = -2. / (appctx->h * appctx->h), sone = -.5 * stwo;
 
+  PetscFunctionBeginUser;
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Compute entries for the locally owned part of the matrix
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
@@ -478,21 +481,25 @@ PetscErrorCode RHSMatrixHeat(TS ts,PetscReal t,Vec X,Mat AA,Mat BB,void *ctx)
 
   mstart = 0;
   v[0]   = 1.0;
-  PetscCall(MatSetValues(A,1,&mstart,1,&mstart,v,INSERT_VALUES));
+  PetscCall(MatSetValues(A, 1, &mstart, 1, &mstart, v, INSERT_VALUES));
   mstart++;
 
   mend--;
   v[0] = 1.0;
-  PetscCall(MatSetValues(A,1,&mend,1,&mend,v,INSERT_VALUES));
+  PetscCall(MatSetValues(A, 1, &mend, 1, &mend, v, INSERT_VALUES));
 
   /*
      Set matrix rows corresponding to interior data.  We construct the
      matrix one row at a time.
   */
-  v[0] = sone; v[1] = stwo; v[2] = sone;
-  for (i=mstart; i<mend; i++) {
-    idx[0] = i-1; idx[1] = i; idx[2] = i+1;
-    PetscCall(MatSetValues(A,1,&i,3,idx,v,INSERT_VALUES));
+  v[0] = sone;
+  v[1] = stwo;
+  v[2] = sone;
+  for (i = mstart; i < mend; i++) {
+    idx[0] = i - 1;
+    idx[1] = i;
+    idx[2] = i + 1;
+    PetscCall(MatSetValues(A, 1, &i, 3, idx, v, INSERT_VALUES));
   }
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -504,38 +511,40 @@ PetscErrorCode RHSMatrixHeat(TS ts,PetscReal t,Vec X,Mat AA,Mat BB,void *ctx)
      Computations can be done while messages are in transition
      by placing code between these two statements.
   */
-  PetscCall(MatAssemblyBegin(A,MAT_FINAL_ASSEMBLY));
-  PetscCall(MatAssemblyEnd(A,MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyEnd(A, MAT_FINAL_ASSEMBLY));
 
   /*
      Set and option to indicate that we will never add a new nonzero location
      to the matrix. If we do, it will generate an error.
   */
-  PetscCall(MatSetOption(A,MAT_NEW_NONZERO_LOCATION_ERR,PETSC_TRUE));
+  PetscCall(MatSetOption(A, MAT_NEW_NONZERO_LOCATION_ERR, PETSC_TRUE));
 
-  return 0;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode IFunctionHeat(TS ts,PetscReal t,Vec X,Vec Xdot,Vec r,void *ctx)
+PetscErrorCode IFunctionHeat(TS ts, PetscReal t, Vec X, Vec Xdot, Vec r, void *ctx)
 {
-  AppCtx         *appctx = (AppCtx*)ctx;     /* user-defined application context */
+  AppCtx *appctx = (AppCtx *)ctx; /* user-defined application context */
 
-  PetscCall(MatMult(appctx->A,X,r));
-  PetscCall(VecAYPX(r,-1.0,Xdot));
-  return 0;
+  PetscFunctionBeginUser;
+  PetscCall(MatMult(appctx->A, X, r));
+  PetscCall(VecAYPX(r, -1.0, Xdot));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode IJacobianHeat(TS ts,PetscReal t,Vec X,Vec Xdot,PetscReal s,Mat A,Mat B,void *ctx)
+PetscErrorCode IJacobianHeat(TS ts, PetscReal t, Vec X, Vec Xdot, PetscReal s, Mat A, Mat B, void *ctx)
 {
-  AppCtx         *appctx = (AppCtx*)ctx;     /* user-defined application context */
+  AppCtx *appctx = (AppCtx *)ctx; /* user-defined application context */
 
-  if (appctx->oshift == s) return 0;
-  PetscCall(MatCopy(appctx->A,A,SAME_NONZERO_PATTERN));
-  PetscCall(MatScale(A,-1));
-  PetscCall(MatShift(A,s));
-  PetscCall(MatCopy(A,B,SAME_NONZERO_PATTERN));
+  PetscFunctionBeginUser;
+  if (appctx->oshift == s) PetscFunctionReturn(PETSC_SUCCESS);
+  PetscCall(MatCopy(appctx->A, A, SAME_NONZERO_PATTERN));
+  PetscCall(MatScale(A, -1));
+  PetscCall(MatShift(A, s));
+  PetscCall(MatCopy(A, B, SAME_NONZERO_PATTERN));
   appctx->oshift = s;
-  return 0;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*TEST
